
package br.com.tabelionatomessias.dao.cart;
/**
 * Sistema: Notarium
 * 
 * Arquivo: AtoslavDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela atoslav
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class AtoslavDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public AtoslavDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(Atoslav atoslav) throws SQLException {
        String sql = "INSERT INTO atoslav " +
                     "(atos_tipato, atos_codigo, atos_livnro, atos_flsnro, atos_flsvrs, atos_datlavratura, atos_escrevente, atos_valcustas, atos_descrobjeto, atos_valobj, atos_arqtexto, atos_datcad, atos_funccad, atos_protnro, atos_natureza, atos_dat_rec_funrejus, atos_val_rec_funrejus) " +
                     "VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, atoslav.getAtosTipato() );

    	ps.setObject( ++idx, atoslav.getAtosCodigo() );

    	ps.setObject( ++idx, atoslav.getAtosLivnro() );

    	ps.setObject( ++idx, atoslav.getAtosFlsnro() );

    	ps.setObject( ++idx, atoslav.getAtosFlsvrs() );

    	ps.setObject( ++idx, atoslav.getAtosDatlavratura() );

    	ps.setObject( ++idx, atoslav.getAtosEscrevente() );

    	ps.setObject( ++idx, atoslav.getAtosValcustas() );

    	ps.setObject( ++idx, atoslav.getAtosDescrobjeto() );

    	ps.setObject( ++idx, atoslav.getAtosValobj() );

    	ps.setObject( ++idx, atoslav.getAtosArqtexto() );

    	ps.setObject( ++idx, atoslav.getAtosDatcad() );

    	ps.setObject( ++idx, atoslav.getAtosFunccad() );

    	ps.setObject( ++idx, atoslav.getAtosProtnro() );

    	ps.setObject( ++idx, atoslav.getAtosNatureza() );

    	ps.setObject( ++idx, atoslav.getAtosDatRecFunrejus() );

    	ps.setObject( ++idx, atoslav.getAtosValRecFunrejus() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(AtoslavDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(Atoslav atoslav) throws SQLException {
        String sql = "UPDATE atoslav SET " +
                     "atos_tipato=?, atos_codigo=?, atos_livnro=?, atos_flsnro=?, atos_flsvrs=?, atos_datlavratura=?, atos_escrevente=?, atos_valcustas=?, atos_descrobjeto=?, atos_valobj=?, atos_arqtexto=?, atos_datcad=?, atos_funccad=?, atos_protnro=?, atos_natureza=?, atos_dat_rec_funrejus=?, atos_val_rec_funrejus=? " +
                     
                     "WHERE atos_codigo=? AND atos_livnro=? AND atos_flsnro=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, atoslav.getAtosTipato() );

    	ps.setObject( ++idx, atoslav.getAtosCodigo() );

    	ps.setObject( ++idx, atoslav.getAtosLivnro() );

    	ps.setObject( ++idx, atoslav.getAtosFlsnro() );

    	ps.setObject( ++idx, atoslav.getAtosFlsvrs() );

    	ps.setObject( ++idx, atoslav.getAtosDatlavratura() );

    	ps.setObject( ++idx, atoslav.getAtosEscrevente() );

    	ps.setObject( ++idx, atoslav.getAtosValcustas() );

    	ps.setObject( ++idx, atoslav.getAtosDescrobjeto() );

    	ps.setObject( ++idx, atoslav.getAtosValobj() );

    	ps.setObject( ++idx, atoslav.getAtosArqtexto() );

    	ps.setObject( ++idx, atoslav.getAtosDatcad() );

    	ps.setObject( ++idx, atoslav.getAtosFunccad() );

    	ps.setObject( ++idx, atoslav.getAtosProtnro() );

    	ps.setObject( ++idx, atoslav.getAtosNatureza() );

    	ps.setObject( ++idx, atoslav.getAtosDatRecFunrejus() );

    	ps.setObject( ++idx, atoslav.getAtosValRecFunrejus() );

    	ps.setObject( ++idx, atoslav.getAtosCodigo() );

    	ps.setObject( ++idx, atoslav.getAtosLivnro() );

    	ps.setObject( ++idx, atoslav.getAtosFlsnro() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(AtoslavDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(Atoslav atoslav) throws SQLException {
        String sql = "DELETE FROM atoslav " +
                     
                     "WHERE atos_codigo=? AND atos_livnro=? AND atos_flsnro=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, atoslav.getAtosCodigo() );

    	ps.setObject( ++idx, atoslav.getAtosLivnro() );

    	ps.setObject( ++idx, atoslav.getAtosFlsnro() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(AtoslavDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
     */
    //public Atoslav selectPK(java.lang.Integer atosCodigo, java.lang.String atosLivnro, java.lang.String atosFlsnro) throws SQLException {
    public Atoslav selectPK(java.lang.Integer atosCodigo) throws SQLException {
    	Atoslav atoslav = null;
        String sql = "SELECT atos_tipato, atos_codigo, atos_livnro, atos_flsnro, atos_flsvrs, atos_datlavratura, atos_escrevente, atos_valcustas, atos_descrobjeto, atos_valobj, atos_arqtexto, atos_datcad, atos_funccad, atos_protnro, atos_natureza, atos_dat_rec_funrejus, atos_val_rec_funrejus " +
                     "FROM atoslav " +            
                     "WHERE atos_codigo=?";
              

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ps.setObject( ++idx, atosCodigo );
	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		atoslav = new Atoslav();
                atoslav.setAtosCodigo( (java.lang.Integer) rs.getObject("atos_codigo") );
    		atoslav.setAtosTipato( (java.lang.Integer) rs.getObject("atos_tipato") );
    		atoslav.setAtosCodigo( (java.lang.Integer) rs.getObject("atos_codigo") );
    		atoslav.setAtosLivnro( (java.lang.String) rs.getObject("atos_livnro") );
    		atoslav.setAtosFlsnro( (java.lang.String) rs.getObject("atos_flsnro") );
    		atoslav.setAtosFlsvrs( (java.lang.String) rs.getObject("atos_flsvrs") );
    		atoslav.setAtosDatlavratura( (java.sql.Date) rs.getObject("atos_datlavratura") );
    		atoslav.setAtosEscrevente( (java.lang.Integer) rs.getObject("atos_escrevente") );
    		atoslav.setAtosValcustas( (java.lang.Double) rs.getObject("atos_valcustas") );
    		atoslav.setAtosDescrobjeto( (java.lang.String) rs.getObject("atos_descrobjeto") );
    		atoslav.setAtosValobj( (java.lang.Double) rs.getObject("atos_valobj") );
    		atoslav.setAtosArqtexto( (java.lang.String) rs.getObject("atos_arqtexto") );
    		atoslav.setAtosDatcad( (java.sql.Date) rs.getObject("atos_datcad") );
    		atoslav.setAtosFunccad( (java.lang.Integer) rs.getObject("atos_funccad") );
    		atoslav.setAtosProtnro( (java.lang.String) rs.getObject("atos_protnro") );
    		atoslav.setAtosNatureza( (java.lang.Integer) rs.getObject("atos_natureza") );
    		atoslav.setAtosDatRecFunrejus( (java.sql.Date) rs.getObject("atos_dat_rec_funrejus") );
    		atoslav.setAtosValRecFunrejus( (java.lang.Double) rs.getObject("atos_val_rec_funrejus") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(AtoslavDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return atoslav;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela atoslav
     */
    public java.util.List <Atoslav> getColecao() throws SQLException {
        Atoslav atoslav = null;
        String sql = "SELECT atos_tipato, atos_codigo, atos_livnro, atos_flsnro, atos_flsvrs, atos_datlavratura, atos_escrevente, atos_valcustas, atos_descrobjeto, atos_valobj, atos_arqtexto, atos_datcad, atos_funccad, atos_protnro, atos_natureza, atos_dat_rec_funrejus, atos_val_rec_funrejus " +
                     "FROM atoslav ";
        PreparedStatement ps = null;
        java.util.ArrayList <Atoslav> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		atoslav = new Atoslav();
      		atoslav.setAtosTipato( (java.lang.Integer) rs.getObject("atos_tipato") );
    		      atoslav.setAtosCodigo( (java.lang.Integer) rs.getObject("atos_codigo") );
    		      atoslav.setAtosLivnro( (java.lang.String) rs.getObject("atos_livnro") );
    		      atoslav.setAtosFlsnro( (java.lang.String) rs.getObject("atos_flsnro") );
    		      atoslav.setAtosFlsvrs( (java.lang.String) rs.getObject("atos_flsvrs") );
    		      atoslav.setAtosDatlavratura( (java.sql.Date) rs.getObject("atos_datlavratura") );
    		      atoslav.setAtosEscrevente( (java.lang.Integer) rs.getObject("atos_escrevente") );
    		      atoslav.setAtosValcustas( (java.lang.Double) rs.getObject("atos_valcustas") );
    		      atoslav.setAtosDescrobjeto( (java.lang.String) rs.getObject("atos_descrobjeto") );
    		      atoslav.setAtosValobj( (java.lang.Double) rs.getObject("atos_valobj") );
    		      atoslav.setAtosArqtexto( (java.lang.String) rs.getObject("atos_arqtexto") );
    		      atoslav.setAtosDatcad( (java.sql.Date) rs.getObject("atos_datcad") );
    		      atoslav.setAtosFunccad( (java.lang.Integer) rs.getObject("atos_funccad") );
    		      atoslav.setAtosProtnro( (java.lang.String) rs.getObject("atos_protnro") );
    		      atoslav.setAtosNatureza( (java.lang.Integer) rs.getObject("atos_natureza") );
    		      atoslav.setAtosDatRecFunrejus( (java.sql.Date) rs.getObject("atos_dat_rec_funrejus") );
    		      
                  colec.add( atoslav );
            }
        } catch( SQLException e ) {
            throw new SQLException(AtoslavDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
    public java.util.List <Atoslav> getAtosLavLikeNome(String nome ) throws SQLException {
         Atoslav atoslav = null;
         String sql = " select a.*,pes_nome,pes_codigo,pes_rg,pes_cpf,a.atos_codigo,atos_tipato, papel"+
         " from ((select p.pes_codigo,pes_nome,pes_rg,pes_cpf,atos_codigo,'OUTORGADO' as papel from pessoa p"+
         " inner join outorgado g"+
         " on p.pes_codigo = g.pes_codigo"+
         "  where pes_nome like Upper(?))"+
         " union"+
         " (select p.pes_codigo,pes_nome,pes_rg,pes_cpf,atos_codigo, 'OUTORGANTE' as papel"+
         " from pessoa p"+
         " inner join outorgante g"+
         " on p.pes_codigo = g.pes_codigo"+
         " where pes_nome like Upper(?))) as pessoa_participacao"+
         " inner join atoslav a"+
         " on a.atos_codigo = pessoa_participacao.atos_codigo"+
         " order by pes_nome,a.atos_codigo"; 
 
        PreparedStatement ps = null;
        java.util.ArrayList <Atoslav> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            int idx = 0;
            ps.setObject( ++idx, nome );
            ps.setObject( ++idx, nome );
            
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		atoslav = new Atoslav();
      		  atoslav.setAtosTipato( (java.lang.Integer) rs.getObject("atos_tipato") );
    	          atoslav.setAtosPessoa((java.lang.Integer) rs.getObject("pes_codigo") );
    	          atoslav.setAtosPapel((java.lang.String) rs.getObject("papel") );
    	          atoslav.setAtosCodigo( (java.lang.Integer) rs.getObject("atos_codigo") );
    	          atoslav.setAtosLivnro((java.lang.String) rs.getObject("atos_livnro") );
    	          atoslav.setAtosFlsnro( (java.lang.String) rs.getObject("atos_flsnro") );
    	          atoslav.setAtosFlsvrs( (java.lang.String) rs.getObject("atos_flsvrs") );
    	          atoslav.setAtosDatlavratura( (java.sql.Date) rs.getObject("atos_datlavratura") );
    	          atoslav.setAtosEscrevente( (java.lang.Integer) rs.getObject("atos_escrevente") );
    	          atoslav.setAtosValcustas( (java.lang.Double) rs.getObject("atos_valcustas") );
    	          atoslav.setAtosDescrobjeto( (java.lang.String) rs.getObject("atos_descrobjeto") );
    	          atoslav.setAtosValobj( (java.lang.Double) rs.getObject("atos_valobj") );
    	          atoslav.setAtosArqtexto( (java.lang.String) rs.getObject("atos_arqtexto") );
    	          atoslav.setAtosDatcad( (java.sql.Date) rs.getObject("atos_datcad") );
    	          atoslav.setAtosFunccad( (java.lang.Integer) rs.getObject("atos_funccad") );
    	          atoslav.setAtosProtnro( (java.lang.String) rs.getObject("atos_protnro") );
    	          atoslav.setAtosNatureza( (java.lang.Integer) rs.getObject("atos_natureza") );
    	          atoslav.setAtosDatRecFunrejus( (java.sql.Date) rs.getObject("atos_dat_rec_funrejus") );
    		      
                  colec.add( atoslav );
            }
        } catch( SQLException e ) {
             throw new SQLException(AtoslavDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
   
    
    
    
    
}
