
package br.com.tabelionatomessias.dao.cart;
/**
 * Sistema: Notarium
 * 
 * Arquivo: AtoslavDocsDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela atoslav_docs
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class AtoslavDocsDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public AtoslavDocsDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(AtoslavDocs atoslavDocs) throws SQLException {
        String sql = "INSERT INTO atoslav_docs " +
                     "(atos_codigo, atos_documento) " +
                     "VALUES (?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, atoslavDocs.getAtosCodigo() );

    	ps.setObject( ++idx, atoslavDocs.getAtosDocumento() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(AtoslavDocsDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(AtoslavDocs atoslavDocs) throws SQLException {
        String sql = "UPDATE atoslav_docs SET " +
                     "atos_codigo=?, atos_documento=? " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, atoslavDocs.getAtosCodigo() );

    	ps.setObject( ++idx, atoslavDocs.getAtosDocumento() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(AtoslavDocsDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(AtoslavDocs atoslavDocs) throws SQLException {
        String sql = "DELETE FROM atoslav_docs " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(AtoslavDocsDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE ";

     */
    public AtoslavDocs selectPK(java.lang.Integer docCodigo) throws SQLException {
    	AtoslavDocs atoslavDocs = null;
        String sql = "SELECT atos_codigo, atos_documento " +
                     "FROM atoslav_docs " +
                      "WHERE atos_codigo = 1";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		atoslavDocs = new AtoslavDocs();
    		atoslavDocs.setAtosCodigo( (java.lang.Integer) rs.getObject("atos_codigo") );
    		atoslavDocs.setAtosDocumento( (byte[]) rs.getObject("atos_documento") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(AtoslavDocsDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return atoslavDocs;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela atoslav_docs
     */
    public java.util.List <AtoslavDocs> getColecao() throws SQLException {
        AtoslavDocs atoslavDocs = null;
        String sql = "SELECT atos_codigo, atos_documento " +
                     "FROM atoslav_docs ";
        PreparedStatement ps = null;
        java.util.ArrayList <AtoslavDocs> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		atoslavDocs = new AtoslavDocs();
      		atoslavDocs.setAtosCodigo( (java.lang.Integer) rs.getObject("atos_codigo") );
    		      atoslavDocs.setAtosDocumento( (byte[]) rs.getObject("atos_documento") );
    		      
                  colec.add( atoslavDocs );
            }
        } catch( SQLException e ) {
            throw new SQLException(AtoslavDocsDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
}
