
package br.com.tabelionatomessias.dao.cart;
/**
 * Sistema: Notarium
 * 
 * Arquivo: BairrosDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela bairros
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class BairrosDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public BairrosDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(Bairros bairros) throws SQLException {
        String sql = "INSERT INTO bairros " +
                     "(cepbai_codigo, cepbai_extenso, cepbai_loc, cepbai_abrev, uf_codigo) " +
                     "VALUES (?, ?, ?, ?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, bairros.getCepbaiCodigo() );

    	ps.setObject( ++idx, bairros.getCepbaiExtenso() );

    	ps.setObject( ++idx, bairros.getCepbaiLoc() );

    	ps.setObject( ++idx, bairros.getCepbaiAbrev() );

    	ps.setObject( ++idx, bairros.getUfCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(BairrosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(Bairros bairros) throws SQLException {
        String sql = "UPDATE bairros SET " +
                     "cepbai_codigo=?, cepbai_extenso=?, cepbai_loc=?, cepbai_abrev=?, uf_codigo=? " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, bairros.getCepbaiCodigo() );

    	ps.setObject( ++idx, bairros.getCepbaiExtenso() );

    	ps.setObject( ++idx, bairros.getCepbaiLoc() );

    	ps.setObject( ++idx, bairros.getCepbaiAbrev() );

    	ps.setObject( ++idx, bairros.getUfCodigo() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(BairrosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(Bairros bairros) throws SQLException {
        String sql = "DELETE FROM bairros " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(BairrosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE ";

     */
    public Bairros selectPK(java.lang.Integer codigo, java.lang.Integer codigolocalidade) throws SQLException {
    	Bairros bairros = null;
        String sql = "SELECT cepbai_codigo, cepbai_extenso, cepbai_loc, cepbai_abrev, uf_codigo " +
                     "FROM bairros " +
                     
                     "WHERE cepbai_codigo = ? and cepbai_loc = ? ";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	ps.setObject(++idx, codigo);
        ps.setObject(++idx, codigolocalidade);
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		bairros = new Bairros();
    		bairros.setCepbaiCodigo( (java.lang.Integer) rs.getObject("cepbai_codigo") );
    		bairros.setCepbaiExtenso( (java.lang.String) rs.getObject("cepbai_extenso") );
    		bairros.setCepbaiLoc( (java.lang.String) rs.getObject("cepbai_loc") );
    		bairros.setCepbaiAbrev( (java.lang.String) rs.getObject("cepbai_abrev") );
    		bairros.setUfCodigo( (java.lang.Integer) rs.getObject("uf_codigo") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(BairrosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return bairros;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela bairros
     */
    public java.util.List <Bairros> getColecao() throws SQLException {
        Bairros bairros = null;
        String sql = "SELECT cepbai_codigo, cepbai_extenso, cepbai_loc, cepbai_abrev, uf_codigo " +
                     "FROM bairros ";
        PreparedStatement ps = null;
        java.util.ArrayList <Bairros> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		bairros = new Bairros();
      		bairros.setCepbaiCodigo( (java.lang.Integer) rs.getObject("cepbai_codigo") );
    		      bairros.setCepbaiExtenso( (java.lang.String) rs.getObject("cepbai_extenso") );
    		      bairros.setCepbaiLoc( (java.lang.String) rs.getObject("cepbai_loc") );
    		      bairros.setCepbaiAbrev( (java.lang.String) rs.getObject("cepbai_abrev") );
    		      bairros.setUfCodigo( (java.lang.Integer) rs.getObject("uf_codigo") );
    		      
                  colec.add( bairros );
            }
        } catch( SQLException e ) {
            throw new SQLException(BairrosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
}
