
package br.com.tabelionatomessias.dao.cart;
/**
 * Sistema: Notarium
 * 
 * Arquivo: CargosDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela cargos
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class CargosDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public CargosDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(Cargos cargos) throws SQLException {
        String sql = "INSERT INTO cargos " +
                     "(cargo_codigo, cargo_descricao) " +
                     "VALUES (?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, cargos.getCargoCodigo() );

    	ps.setObject( ++idx, cargos.getCargoDescricao() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(CargosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(Cargos cargos) throws SQLException {
        String sql = "UPDATE cargos SET " +
                     "cargo_codigo=?, cargo_descricao=? " +
                     
                     "WHERE cargo_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, cargos.getCargoCodigo() );

    	ps.setObject( ++idx, cargos.getCargoDescricao() );

    	ps.setObject( ++idx, cargos.getCargoCodigo() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(CargosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(Cargos cargos) throws SQLException {
        String sql = "DELETE FROM cargos " +
                     
                     "WHERE cargo_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, cargos.getCargoCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(CargosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE cargo_codigo=?";

     */
    public Cargos selectPK(java.lang.Integer cargoCodigo) throws SQLException {
    	Cargos cargos = null;
        String sql = "SELECT cargo_codigo, cargo_descricao " +
                     "FROM cargos " +
                     
                     "WHERE cargo_codigo=?";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ps.setObject( ++idx, cargoCodigo );
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		cargos = new Cargos();
    		cargos.setCargoCodigo( (java.lang.Integer) rs.getObject("cargo_codigo") );
    		cargos.setCargoDescricao( (java.lang.String) rs.getObject("cargo_descricao") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(CargosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return cargos;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela cargos
     */
    public java.util.List <Cargos> getColecao() throws SQLException {
        Cargos cargos = null;
        String sql = "SELECT cargo_codigo, cargo_descricao " +
                     "FROM cargos ";
        PreparedStatement ps = null;
        java.util.ArrayList <Cargos> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		cargos = new Cargos();
      		cargos.setCargoCodigo( (java.lang.Integer) rs.getObject("cargo_codigo") );
    		      cargos.setCargoDescricao( (java.lang.String) rs.getObject("cargo_descricao") );
    		      
                  colec.add( cargos );
            }
        } catch( SQLException e ) {
            throw new SQLException(CargosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
}
