
package br.com.tabelionatomessias.dao.cart;
/**
 * Sistema: Notarium
 * 
 * Arquivo: CargosPkeyDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela cargos_pkey
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class CargosPkeyDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public CargosPkeyDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(CargosPkey cargosPkey) throws SQLException {
        String sql = "INSERT INTO cargos_pkey " +
                     "(cargo_codigo) " +
                     "VALUES (?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, cargosPkey.getCargoCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(CargosPkeyDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(CargosPkey cargosPkey) throws SQLException {
        String sql = "UPDATE cargos_pkey SET " +
                     "cargo_codigo=? " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, cargosPkey.getCargoCodigo() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(CargosPkeyDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(CargosPkey cargosPkey) throws SQLException {
        String sql = "DELETE FROM cargos_pkey " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(CargosPkeyDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE ";

     */
    public CargosPkey selectPK() throws SQLException {
    	CargosPkey cargosPkey = null;
        String sql = "SELECT cargo_codigo " +
                     "FROM cargos_pkey " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		cargosPkey = new CargosPkey();
    		cargosPkey.setCargoCodigo( (java.lang.Integer) rs.getObject("cargo_codigo") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(CargosPkeyDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return cargosPkey;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela cargos_pkey
     */
    public java.util.List <CargosPkey> getColecao() throws SQLException {
        CargosPkey cargosPkey = null;
        String sql = "SELECT cargo_codigo " +
                     "FROM cargos_pkey ";
        PreparedStatement ps = null;
        java.util.ArrayList <CargosPkey> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		cargosPkey = new CargosPkey();
      		cargosPkey.setCargoCodigo( (java.lang.Integer) rs.getObject("cargo_codigo") );
    		      
                  colec.add( cargosPkey );
            }
        } catch( SQLException e ) {
            throw new SQLException(CargosPkeyDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
}
