
package br.com.tabelionatomessias.dao.cart;
/**
 * Sistema: Notarium
 * 
 * Arquivo: CartorioDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela cartorio
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class CartorioDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public CartorioDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(Cartorio cartorio) throws SQLException {
        String sql = "INSERT INTO cartorio " +
                     "(crt_codigo, crt_nome, crt_telefone, ceploc_codigo, crt_cep, cepbai_codigo, crt_complemento, crt_nro, crt_status, crt_data_cadastro, crt_ult_atualizacao, func_codigo) " +
                     "VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, cartorio.getCrtCodigo() );

    	ps.setObject( ++idx, cartorio.getCrtNome() );

    	ps.setObject( ++idx, cartorio.getCrtTelefone() );

    	ps.setObject( ++idx, cartorio.getCeplocCodigo() );

    	ps.setObject( ++idx, cartorio.getCrtCep() );

    	ps.setObject( ++idx, cartorio.getCepbaiCodigo() );

    	ps.setObject( ++idx, cartorio.getCrtComplemento() );

    	ps.setObject( ++idx, cartorio.getCrtNro() );

    	ps.setObject( ++idx, cartorio.getCrtStatus() );

    	ps.setObject( ++idx, cartorio.getCrtDataCadastro() );

    	ps.setObject( ++idx, cartorio.getCrtUltAtualizacao() );

    	ps.setObject( ++idx, cartorio.getFuncCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(CartorioDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(Cartorio cartorio) throws SQLException {
        String sql = "UPDATE cartorio SET " +
                     "crt_codigo=?, crt_nome=?, crt_telefone=?, ceploc_codigo=?, crt_cep=?, cepbai_codigo=?, crt_complemento=?, crt_nro=?, crt_status=?, crt_data_cadastro=?, crt_ult_atualizacao=?, func_codigo=? " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, cartorio.getCrtCodigo() );

    	ps.setObject( ++idx, cartorio.getCrtNome() );

    	ps.setObject( ++idx, cartorio.getCrtTelefone() );

    	ps.setObject( ++idx, cartorio.getCeplocCodigo() );

    	ps.setObject( ++idx, cartorio.getCrtCep() );

    	ps.setObject( ++idx, cartorio.getCepbaiCodigo() );

    	ps.setObject( ++idx, cartorio.getCrtComplemento() );

    	ps.setObject( ++idx, cartorio.getCrtNro() );

    	ps.setObject( ++idx, cartorio.getCrtStatus() );

    	ps.setObject( ++idx, cartorio.getCrtDataCadastro() );

    	ps.setObject( ++idx, cartorio.getCrtUltAtualizacao() );

    	ps.setObject( ++idx, cartorio.getFuncCodigo() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(CartorioDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(Cartorio cartorio) throws SQLException {
        String sql = "DELETE FROM cartorio " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(CartorioDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE ";

     */
    public Cartorio selectPK(java.lang.Integer crtcodigo) throws SQLException {
    	Cartorio cartorio = null;
        String sql = "SELECT crt_codigo, crt_nome, crt_telefone, ceploc_codigo, crt_cep, cepbai_codigo, crt_complemento, crt_nro, crt_status, crt_data_cadastro, crt_ult_atualizacao, func_codigo " +
                     "FROM cartorio " +
                     
                     "WHERE crt_codigo=? ";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	ps.setObject(++idx,crtcodigo);
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		cartorio = new Cartorio();
    		cartorio.setCrtCodigo( (java.lang.Integer) rs.getObject("crt_codigo") );
    		cartorio.setCrtNome( (java.lang.String) rs.getObject("crt_nome") );
    		cartorio.setCrtTelefone( (java.lang.String) rs.getObject("crt_telefone") );
    		cartorio.setCeplocCodigo( (java.lang.Integer) rs.getObject("ceploc_codigo") );
    		cartorio.setCrtCep( (java.lang.Integer) rs.getObject("crt_cep") );
    		cartorio.setCepbaiCodigo( (java.lang.Integer) rs.getObject("cepbai_codigo") );
    		cartorio.setCrtComplemento( (java.lang.String) rs.getObject("crt_complemento") );
    		cartorio.setCrtNro( (java.lang.Integer) rs.getObject("crt_nro") );
    		cartorio.setCrtStatus( (java.lang.Integer) rs.getObject("crt_status") );
    		cartorio.setCrtDataCadastro( (java.sql.Date) rs.getObject("crt_data_cadastro") );
    		cartorio.setCrtUltAtualizacao( (java.sql.Date) rs.getObject("crt_ult_atualizacao") );
    		cartorio.setFuncCodigo( (java.lang.Integer) rs.getObject("func_codigo") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(CartorioDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return cartorio;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela cartorio
     */
    public java.util.List <Cartorio> getColecao() throws SQLException {
        Cartorio cartorio = null;
        String sql = "SELECT crt_codigo, crt_nome, crt_telefone, ceploc_codigo, crt_cep, cepbai_codigo, crt_complemento, crt_nro, crt_status, crt_data_cadastro, crt_ult_atualizacao, func_codigo " +
                     "FROM cartorio ";
        PreparedStatement ps = null;
        java.util.ArrayList <Cartorio> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		cartorio = new Cartorio();
      		cartorio.setCrtCodigo( (java.lang.Integer) rs.getObject("crt_codigo") );
    		      cartorio.setCrtNome( (java.lang.String) rs.getObject("crt_nome") );
    		      cartorio.setCrtTelefone( (java.lang.String) rs.getObject("crt_telefone") );
    		      cartorio.setCeplocCodigo( (java.lang.Integer) rs.getObject("ceploc_codigo") );
    		      cartorio.setCrtCep( (java.lang.Integer) rs.getObject("crt_cep") );
    		      cartorio.setCepbaiCodigo( (java.lang.Integer) rs.getObject("cepbai_codigo") );
    		      cartorio.setCrtComplemento( (java.lang.String) rs.getObject("crt_complemento") );
    		      cartorio.setCrtNro( (java.lang.Integer) rs.getObject("crt_nro") );
    		      cartorio.setCrtStatus( (java.lang.Integer) rs.getObject("crt_status") );
    		      cartorio.setCrtDataCadastro( (java.sql.Date) rs.getObject("crt_data_cadastro") );
    		      cartorio.setCrtUltAtualizacao( (java.sql.Date) rs.getObject("crt_ult_atualizacao") );
    		      cartorio.setFuncCodigo( (java.lang.Integer) rs.getObject("func_codigo") );
    		      
                  colec.add( cartorio );
            }
        } catch( SQLException e ) {
            throw new SQLException(CartorioDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
}
