
package br.com.tabelionatomessias.dao.cart;
/**
 * Sistema: Notarium
 * 
 * Arquivo: FuncionarioDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela funcionario
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class FuncionarioDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public FuncionarioDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(Funcionario funcionario) throws SQLException {
        String sql = "INSERT INTO funcionario " +
                     "(func_codigo, func_nome, func_funcao, func_data_admissao, func_data_demissao, func_ult_atualizacao, func_rua, func_cep, func_bairro, func_cidade, func_uf, func_telefone, func_pes_contato, func_nivel, func_login, func_senha, func_data_nascto, img_assinatura, img_rubrica) " +
                     "VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, funcionario.getFuncCodigo() );

    	ps.setObject( ++idx, funcionario.getFuncNome() );

    	ps.setObject( ++idx, funcionario.getFuncFuncao() );

    	ps.setObject( ++idx, funcionario.getFuncDataAdmissao() );

    	ps.setObject( ++idx, funcionario.getFuncDataDemissao() );

    	ps.setObject( ++idx, funcionario.getFuncUltAtualizacao() );

    	ps.setObject( ++idx, funcionario.getFuncRua() );

    	ps.setObject( ++idx, funcionario.getFuncCep() );

    	ps.setObject( ++idx, funcionario.getFuncBairro() );

    	ps.setObject( ++idx, funcionario.getFuncCidade() );

    	ps.setObject( ++idx, funcionario.getFuncUf() );

    	ps.setObject( ++idx, funcionario.getFuncTelefone() );

    	ps.setObject( ++idx, funcionario.getFuncPesContato() );

    	ps.setObject( ++idx, funcionario.getFuncNivel() );

    	ps.setObject( ++idx, funcionario.getFuncLogin() );

    	ps.setObject( ++idx, funcionario.getFuncSenha() );

    	ps.setObject( ++idx, funcionario.getFuncDataNascto() );

    	ps.setObject( ++idx, funcionario.getImgAssinatura() );

    	ps.setObject( ++idx, funcionario.getImgRubrica() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(FuncionarioDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(Funcionario funcionario) throws SQLException {
        String sql = "UPDATE funcionario SET " +
                     "func_codigo=?, func_nome=?, func_funcao=?, func_data_admissao=?, func_data_demissao=?, func_ult_atualizacao=?, func_rua=?, func_cep=?, func_bairro=?, func_cidade=?, func_uf=?, func_telefone=?, func_pes_contato=?, func_nivel=?, func_login=?, func_senha=?, func_data_nascto=?, img_assinatura=?, img_rubrica=? " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, funcionario.getFuncCodigo() );

    	ps.setObject( ++idx, funcionario.getFuncNome() );

    	ps.setObject( ++idx, funcionario.getFuncFuncao() );

    	ps.setObject( ++idx, funcionario.getFuncDataAdmissao() );

    	ps.setObject( ++idx, funcionario.getFuncDataDemissao() );

    	ps.setObject( ++idx, funcionario.getFuncUltAtualizacao() );

    	ps.setObject( ++idx, funcionario.getFuncRua() );

    	ps.setObject( ++idx, funcionario.getFuncCep() );

    	ps.setObject( ++idx, funcionario.getFuncBairro() );

    	ps.setObject( ++idx, funcionario.getFuncCidade() );

    	ps.setObject( ++idx, funcionario.getFuncUf() );

    	ps.setObject( ++idx, funcionario.getFuncTelefone() );

    	ps.setObject( ++idx, funcionario.getFuncPesContato() );

    	ps.setObject( ++idx, funcionario.getFuncNivel() );

    	ps.setObject( ++idx, funcionario.getFuncLogin() );

    	ps.setObject( ++idx, funcionario.getFuncSenha() );

    	ps.setObject( ++idx, funcionario.getFuncDataNascto() );

    	ps.setObject( ++idx, funcionario.getImgAssinatura() );

    	ps.setObject( ++idx, funcionario.getImgRubrica() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(FuncionarioDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(Funcionario funcionario) throws SQLException {
        String sql = "DELETE FROM funcionario " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(FuncionarioDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE ";

     */
    public Funcionario selectPK() throws SQLException {
    	Funcionario funcionario = null;
        String sql = "SELECT func_codigo, func_nome, func_funcao, func_data_admissao, func_data_demissao, func_ult_atualizacao, func_rua, func_cep, func_bairro, func_cidade, func_uf, func_telefone, func_pes_contato, func_nivel, func_login, func_senha, func_data_nascto, img_assinatura, img_rubrica " +
                     "FROM funcionario " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		funcionario = new Funcionario();
    		funcionario.setFuncCodigo( (java.lang.Integer) rs.getObject("func_codigo") );
    		funcionario.setFuncNome( (java.lang.String) rs.getObject("func_nome") );
    		funcionario.setFuncFuncao( (java.lang.Integer) rs.getObject("func_funcao") );
    		funcionario.setFuncDataAdmissao( (java.sql.Date) rs.getObject("func_data_admissao") );
    		funcionario.setFuncDataDemissao( (java.sql.Date) rs.getObject("func_data_demissao") );
    		funcionario.setFuncUltAtualizacao( (java.sql.Date) rs.getObject("func_ult_atualizacao") );
    		funcionario.setFuncRua( (java.lang.String) rs.getObject("func_rua") );
    		funcionario.setFuncCep( (java.lang.String) rs.getObject("func_cep") );
    		funcionario.setFuncBairro( (java.lang.String) rs.getObject("func_bairro") );
    		funcionario.setFuncCidade( (java.lang.String) rs.getObject("func_cidade") );
    		funcionario.setFuncUf( (java.lang.String) rs.getObject("func_uf") );
    		funcionario.setFuncTelefone( (java.lang.String) rs.getObject("func_telefone") );
    		funcionario.setFuncPesContato( (java.lang.String) rs.getObject("func_pes_contato") );
    		funcionario.setFuncNivel( (java.lang.Integer) rs.getObject("func_nivel") );
    		funcionario.setFuncLogin( (java.lang.String) rs.getObject("func_login") );
    		funcionario.setFuncSenha( (java.lang.String) rs.getObject("func_senha") );
    		funcionario.setFuncDataNascto( (java.sql.Date) rs.getObject("func_data_nascto") );
    		funcionario.setImgAssinatura( (java.lang.Integer) rs.getObject("img_assinatura") );
    		funcionario.setImgRubrica( (java.lang.Integer) rs.getObject("img_rubrica") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(FuncionarioDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return funcionario;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela funcionario
     */
    public java.util.List <Funcionario> getColecao() throws SQLException {
        Funcionario funcionario = null;
        String sql = "SELECT func_codigo, func_nome, func_funcao, func_data_admissao, func_data_demissao, func_ult_atualizacao, func_rua, func_cep, func_bairro, func_cidade, func_uf, func_telefone, func_pes_contato, func_nivel, func_login, func_senha, func_data_nascto, img_assinatura, img_rubrica " +
                     "FROM funcionario ";
        PreparedStatement ps = null;
        java.util.ArrayList <Funcionario> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		funcionario = new Funcionario();
      		funcionario.setFuncCodigo( (java.lang.Integer) rs.getObject("func_codigo") );
    		      funcionario.setFuncNome( (java.lang.String) rs.getObject("func_nome") );
    		      funcionario.setFuncFuncao( (java.lang.Integer) rs.getObject("func_funcao") );
    		      funcionario.setFuncDataAdmissao( (java.sql.Date) rs.getObject("func_data_admissao") );
    		      funcionario.setFuncDataDemissao( (java.sql.Date) rs.getObject("func_data_demissao") );
    		      funcionario.setFuncUltAtualizacao( (java.sql.Date) rs.getObject("func_ult_atualizacao") );
    		      funcionario.setFuncRua( (java.lang.String) rs.getObject("func_rua") );
    		      funcionario.setFuncCep( (java.lang.String) rs.getObject("func_cep") );
    		      funcionario.setFuncBairro( (java.lang.String) rs.getObject("func_bairro") );
    		      funcionario.setFuncCidade( (java.lang.String) rs.getObject("func_cidade") );
    		      funcionario.setFuncUf( (java.lang.String) rs.getObject("func_uf") );
    		      funcionario.setFuncTelefone( (java.lang.String) rs.getObject("func_telefone") );
    		      funcionario.setFuncPesContato( (java.lang.String) rs.getObject("func_pes_contato") );
    		      funcionario.setFuncNivel( (java.lang.Integer) rs.getObject("func_nivel") );
    		      funcionario.setFuncLogin( (java.lang.String) rs.getObject("func_login") );
    		      funcionario.setFuncSenha( (java.lang.String) rs.getObject("func_senha") );
    		      funcionario.setFuncDataNascto( (java.sql.Date) rs.getObject("func_data_nascto") );
    		      funcionario.setImgAssinatura( (java.lang.Integer) rs.getObject("img_assinatura") );
    		      funcionario.setImgRubrica( (java.lang.Integer) rs.getObject("img_rubrica") );
    		      
                  colec.add( funcionario );
            }
        } catch( SQLException e ) {
            throw new SQLException(FuncionarioDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
}
