
package br.com.tabelionatomessias.dao.cart;
/**
 * Sistema: Notarium
 * 
 * Arquivo: NaturezaDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela natureza
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class NaturezaDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public NaturezaDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(Natureza natureza) throws SQLException {
        String sql = "INSERT INTO natureza " +
                     "(natureza_codigo, natureza_tipo, natureza_descricao, natureza_data_cadastro, natureza_ult_atualizacao, natureza_func) " +
                     "VALUES (?, ?, ?, ?, ?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, natureza.getNaturezaCodigo() );

    	ps.setObject( ++idx, natureza.getNaturezaTipo() );

    	ps.setObject( ++idx, natureza.getNaturezaDescricao() );

    	ps.setObject( ++idx, natureza.getNaturezaDataCadastro() );

    	ps.setObject( ++idx, natureza.getNaturezaUltAtualizacao() );

    	ps.setObject( ++idx, natureza.getNaturezaFunc() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(NaturezaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(Natureza natureza) throws SQLException {
        String sql = "UPDATE natureza SET " +
                     "natureza_codigo=?, natureza_tipo=?, natureza_descricao=?, natureza_data_cadastro=?, natureza_ult_atualizacao=?, natureza_func=? " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, natureza.getNaturezaCodigo() );

    	ps.setObject( ++idx, natureza.getNaturezaTipo() );

    	ps.setObject( ++idx, natureza.getNaturezaDescricao() );

    	ps.setObject( ++idx, natureza.getNaturezaDataCadastro() );

    	ps.setObject( ++idx, natureza.getNaturezaUltAtualizacao() );

    	ps.setObject( ++idx, natureza.getNaturezaFunc() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(NaturezaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(Natureza natureza) throws SQLException {
        String sql = "DELETE FROM natureza " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(NaturezaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE ";

     */
    public Natureza selectPK(java.lang.Integer nattipo, java.lang.Integer natcod) throws SQLException {
    	Natureza natureza = null;
        String sql = "SELECT natureza_codigo, natureza_tipo, natureza_descricao, natureza_data_cadastro, natureza_ult_atualizacao, natureza_func " +
                     "FROM natureza " +
                     
                     "WHERE natureza_tipo = ? and natureza_codigo = ? ";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
        
        ps.setObject( ++idx, nattipo );
        
        ps.setObject( ++idx, natcod );
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		natureza = new Natureza();
    		natureza.setNaturezaCodigo( (java.lang.Integer) rs.getObject("natureza_codigo") );
    		natureza.setNaturezaTipo( (java.lang.Integer) rs.getObject("natureza_tipo") );
    		natureza.setNaturezaDescricao( (java.lang.String) rs.getObject("natureza_descricao") );
    		natureza.setNaturezaDataCadastro( (java.sql.Date) rs.getObject("natureza_data_cadastro") );
    		natureza.setNaturezaUltAtualizacao( (java.sql.Date) rs.getObject("natureza_ult_atualizacao") );
    		natureza.setNaturezaFunc( (java.lang.Integer) rs.getObject("natureza_func") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(NaturezaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return natureza;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela natureza
     */
    public java.util.List <Natureza> getColecao(String tipato) throws SQLException {
        Natureza natureza = null;
        String sql;
        if (tipato != "") {
          sql = "SELECT natureza_codigo, natureza_tipo, natureza_descricao, natureza_data_cadastro, natureza_ult_atualizacao, natureza_func " +
                       "FROM natureza where natureza_tipo=? order by natureza_descricao ";
        } else {
          sql = "SELECT natureza_codigo, natureza_tipo, natureza_descricao, natureza_data_cadastro, natureza_ult_atualizacao, natureza_func " +
                       "FROM natureza order by natureza_descricao ";
        }
        PreparedStatement ps = null;
        java.util.ArrayList <Natureza> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            int idx = 0;
            if (tipato != "") {
              ps.setObject( ++idx, tipato );
            }
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		natureza = new Natureza();
      		natureza.setNaturezaCodigo( (java.lang.Integer) rs.getObject("natureza_codigo") );
    		      natureza.setNaturezaTipo( (java.lang.Integer) rs.getObject("natureza_tipo") );
    		      natureza.setNaturezaDescricao( (java.lang.String) rs.getObject("natureza_descricao") );
    		      natureza.setNaturezaDataCadastro( (java.sql.Date) rs.getObject("natureza_data_cadastro") );
    		      natureza.setNaturezaUltAtualizacao( (java.sql.Date) rs.getObject("natureza_ult_atualizacao") );
    		      natureza.setNaturezaFunc( (java.lang.Integer) rs.getObject("natureza_func") );
    		      
                  colec.add( natureza );
            }
        } catch( SQLException e ) {
            throw new SQLException(NaturezaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
}
