
package br.com.tabelionatomessias.dao.cart;
/**
 * Sistema: Notarium
 * 
 * Arquivo: PessoaDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela pessoa
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class PessoaDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public PessoaDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(Pessoa pessoa) throws SQLException {
        String sql = "INSERT INTO pessoa " +
                     "(pes_codigo, pes_nome, pes_nacionalidade, pes_data_nascto, " +
                     "pes_local_nascto, pes_loc_nasc_uf, pes_sexo, pes_est_civil, " +
                     "pes_reg_bens, pes_nome_conj, pes_profissao, pes_rg, pes_rg_dat_exp, " +
                     "pes_cpf, pes_doc_profissao, pes_pai, pes_mae, pes_end_cidade, " +
                     "pes_end_bairro, pes_end_uf, pes_end_cep, pes_end_nro, pes_complemento, " +
                     "pes_telefone1, pes_telefone2, pes_data_cadastro, pes_ult_atualizacao, " +
                     "func_codigo, pes_observacao, pes_sobrenome, pes_status, pes_rg_org_emis, " +
                     "pes_fic, pes_atoslav) " +
                     "VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, pessoa.getPesCodigo() );
    	ps.setObject( ++idx, pessoa.getPesNome() );
    	ps.setObject( ++idx, pessoa.getPesNacionalidade() );
    	ps.setObject( ++idx, pessoa.getPesDataNascto() );
    	ps.setObject( ++idx, pessoa.getPesLocalNascto() );
    	ps.setObject( ++idx, pessoa.getPesLocNascUf() );
    	ps.setObject( ++idx, pessoa.getPesSexo() );
    	ps.setObject( ++idx, pessoa.getPesEstCivil() );
    	ps.setObject( ++idx, pessoa.getPesRegBens() );
    	ps.setObject( ++idx, pessoa.getPesNomeConj() );
    	ps.setObject( ++idx, pessoa.getPesProfissao() );
    	ps.setObject( ++idx, pessoa.getPesRg() );
    	ps.setObject( ++idx, pessoa.getPesRgDatExp() );
    	ps.setObject( ++idx, pessoa.getPesCpf() );
    	ps.setObject( ++idx, pessoa.getPesDocProfissao() );
    	ps.setObject( ++idx, pessoa.getPesPai() );
    	ps.setObject( ++idx, pessoa.getPesMae() );
    	ps.setObject( ++idx, pessoa.getPesEndCidade() );
    	ps.setObject( ++idx, pessoa.getPesEndBairro() );
    	ps.setObject( ++idx, pessoa.getPesEndUf() );
    	ps.setObject( ++idx, pessoa.getPesEndCep() );
    	ps.setObject( ++idx, pessoa.getPesEndNro() );
    	ps.setObject( ++idx, pessoa.getPesComplemento() );
    	ps.setObject( ++idx, pessoa.getPesTelefone1() );
    	ps.setObject( ++idx, pessoa.getPesTelefone2() );
    	ps.setObject( ++idx, pessoa.getPesDataCadastro() );
    	ps.setObject( ++idx, pessoa.getPesUltAtualizacao() );
    	ps.setObject( ++idx, pessoa.getFuncCodigo() );
    	ps.setObject( ++idx, pessoa.getPesObservacao() );
    	ps.setObject( ++idx, pessoa.getPesSobrenome() );
    	ps.setObject( ++idx, pessoa.getPesStatus() );
    	ps.setObject( ++idx, pessoa.getPesRgOrgEmis() );
    	ps.setObject( ++idx, pessoa.getPesFic() );
    	ps.setObject( ++idx, pessoa.getPesAtoslav() );
    	
        ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(PessoaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(Pessoa pessoa) throws SQLException {
        String sql = "UPDATE pessoa SET " +
                     "pes_codigo=?, pes_nome=?, pes_nacionalidade=?, pes_data_nascto=?, " +
                     "pes_local_nascto=?, pes_loc_nasc_uf=?, pes_sexo=?, pes_est_civil=?, " +
                     "pes_reg_bens=?, pes_nome_conj=?, pes_profissao=?, pes_rg=?, " +
                     "pes_rg_dat_exp=?, pes_cpf=?, pes_doc_profissao=?, pes_pai=?, " +
                     "pes_mae=?, pes_end_cidade=?, pes_end_bairro=?, pes_end_uf=?, " +
                     "pes_end_cep=?, pes_end_nro=?, pes_complemento=?, pes_telefone1=?, " +
                     "pes_telefone2=?, pes_data_cadastro=?, pes_ult_atualizacao=?, " +
                     "func_codigo=?, pes_observacao=?, pes_sobrenome=?, pes_status=?, " +
                     "pes_rg_org_emis=?, pes_fic=?, pes_atoslav=?, pes_login=?, pes_senha=? " +
                     "WHERE pes_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, pessoa.getPesCodigo() );
    	ps.setObject( ++idx, pessoa.getPesNome() );
    	ps.setObject( ++idx, pessoa.getPesNacionalidade() );
    	ps.setObject( ++idx, pessoa.getPesDataNascto() );
    	ps.setObject( ++idx, pessoa.getPesLocalNascto() );
    	ps.setObject( ++idx, pessoa.getPesLocNascUf() );
    	ps.setObject( ++idx, pessoa.getPesSexo() );
    	ps.setObject( ++idx, pessoa.getPesEstCivil() );
    	ps.setObject( ++idx, pessoa.getPesRegBens() );
    	ps.setObject( ++idx, pessoa.getPesNomeConj() );
    	ps.setObject( ++idx, pessoa.getPesProfissao() );
    	ps.setObject( ++idx, pessoa.getPesRg() );
    	ps.setObject( ++idx, pessoa.getPesRgDatExp() );
    	ps.setObject( ++idx, pessoa.getPesCpf() );
    	ps.setObject( ++idx, pessoa.getPesDocProfissao() );
    	ps.setObject( ++idx, pessoa.getPesPai() );
    	ps.setObject( ++idx, pessoa.getPesMae() );
    	ps.setObject( ++idx, pessoa.getPesEndCidade() );
    	ps.setObject( ++idx, pessoa.getPesEndBairro() );
    	ps.setObject( ++idx, pessoa.getPesEndUf() );
    	ps.setObject( ++idx, pessoa.getPesEndCep() );
    	ps.setObject( ++idx, pessoa.getPesEndNro() );
    	ps.setObject( ++idx, pessoa.getPesComplemento() );
    	ps.setObject( ++idx, pessoa.getPesTelefone1() );
    	ps.setObject( ++idx, pessoa.getPesTelefone2() );
    	ps.setObject( ++idx, pessoa.getPesDataCadastro() );
    	ps.setObject( ++idx, pessoa.getPesUltAtualizacao() );
    	ps.setObject( ++idx, pessoa.getFuncCodigo() );
    	ps.setObject( ++idx, pessoa.getPesObservacao() );
    	ps.setObject( ++idx, pessoa.getPesSobrenome() );
    	ps.setObject( ++idx, pessoa.getPesStatus() );
    	ps.setObject( ++idx, pessoa.getPesRgOrgEmis() );
    	ps.setObject( ++idx, pessoa.getPesFic() );
    	ps.setObject( ++idx, pessoa.getPesAtoslav() );
        ps.setObject( ++idx, pessoa.getPesLogin() );
        ps.setObject( ++idx, pessoa.getPesSenha() );
        ps.setObject( ++idx, pessoa.getPesCodigo() );
        
        ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(PessoaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    
    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void updateCertificado(Pessoa pessoa) throws SQLException {
        String sql = "UPDATE pessoa SET pes_certificado=? WHERE pes_codigo=?";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, pessoa.getPesCertificado() );
        ps.setObject( ++idx, pessoa.getPesCodigo());
        
        ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(PessoaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }
    
    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(Pessoa pessoa) throws SQLException {
        String sql = "DELETE FROM pessoa WHERE pes_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, pessoa.getPesCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(PessoaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     */
    public Pessoa selectPK(java.lang.Integer pesCodigo) throws SQLException {
    	Pessoa pessoa = null;
        String sql = "SELECT pes_codigo, pes_nome, pes_nacionalidade, pes_data_nascto, " +
                     "pes_local_nascto, pes_loc_nasc_uf, pes_sexo, pes_est_civil, " +
                     "pes_reg_bens, pes_nome_conj, pes_profissao, pes_rg, pes_rg_dat_exp, " +
                     "pes_cpf, pes_doc_profissao, pes_pai, pes_mae, pes_end_cidade, " +
                     "pes_end_bairro, pes_end_uf, pes_end_cep, pes_end_nro, pes_complemento, " +
                     "pes_telefone1, pes_telefone2, pes_data_cadastro, pes_ult_atualizacao, " +
                     "func_codigo, pes_observacao, pes_sobrenome, pes_status, pes_rg_org_emis, " +
                     "pes_fic, pes_atoslav, pes_login, pes_senha, pes_autonomo, pes_naturalizado, " +
                     "pes_aposentado, pes_certificado FROM pessoa WHERE pes_codigo=? ";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ps.setObject( ++idx, pesCodigo );
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		pessoa = new Pessoa();
    		pessoa.setPesCodigo( (java.lang.Integer) rs.getObject("pes_codigo") );
    		pessoa.setPesNome( (java.lang.String) rs.getObject("pes_nome") );
    		pessoa.setPesNacionalidade( (java.lang.Integer) rs.getObject("pes_nacionalidade") );
    		pessoa.setPesDataNascto( (java.util.Date) rs.getObject("pes_data_nascto") );
    		pessoa.setPesLocalNascto( (java.lang.Integer) rs.getObject("pes_local_nascto") );
    		pessoa.setPesLocNascUf( (java.lang.Integer) rs.getObject("pes_loc_nasc_uf") );
    		pessoa.setPesSexo( (java.lang.Integer) rs.getObject("pes_sexo") );
    		pessoa.setPesEstCivil( (java.lang.Integer) rs.getObject("pes_est_civil") );
    		pessoa.setPesRegBens( (java.lang.Integer) rs.getObject("pes_reg_bens") );
    		pessoa.setPesNomeConj( (java.lang.String) rs.getObject("pes_nome_conj") );
    		pessoa.setPesProfissao( (java.lang.Integer) rs.getObject("pes_profissao") );
    		pessoa.setPesRg( (java.lang.String) rs.getObject("pes_rg") );
    		pessoa.setPesRgDatExp( (java.util.Date) rs.getObject("pes_rg_dat_exp") );
    		pessoa.setPesCpf( (java.lang.String) rs.getObject("pes_cpf") );
    		pessoa.setPesDocProfissao( (java.lang.String) rs.getObject("pes_doc_profissao") );
    		pessoa.setPesPai( (java.lang.String) rs.getObject("pes_pai") );
    		pessoa.setPesMae( (java.lang.String) rs.getObject("pes_mae") );
    		pessoa.setPesEndCidade( (java.lang.Integer) rs.getObject("pes_end_cidade") );
    		pessoa.setPesEndBairro( (java.lang.Integer) rs.getObject("pes_end_bairro") );
    		pessoa.setPesEndUf( (java.lang.Integer) rs.getObject("pes_end_uf") );
    		pessoa.setPesEndCep( (java.lang.String) rs.getObject("pes_end_cep") );
    		pessoa.setPesEndNro( (java.lang.Integer) rs.getObject("pes_end_nro") );
    		pessoa.setPesComplemento( (java.lang.String) rs.getObject("pes_complemento") );
    		pessoa.setPesTelefone1( (java.lang.String) rs.getObject("pes_telefone1") );
    		pessoa.setPesTelefone2( (java.lang.String) rs.getObject("pes_telefone2") );
    		pessoa.setPesDataCadastro( (java.util.Date) rs.getObject("pes_data_cadastro") );
    		pessoa.setPesUltAtualizacao( (java.util.Date) rs.getObject("pes_ult_atualizacao") );
    		pessoa.setFuncCodigo( (java.lang.Integer) rs.getObject("func_codigo") );
    		pessoa.setPesObservacao( (java.lang.String) rs.getObject("pes_observacao") );
    		pessoa.setPesSobrenome( (java.lang.String) rs.getObject("pes_sobrenome") );
    		pessoa.setPesStatus( (java.lang.Short) rs.getObject("pes_status") );
    		pessoa.setPesRgOrgEmis( (java.lang.Integer) rs.getObject("pes_rg_org_emis") );
    		pessoa.setPesFic( (java.lang.Boolean) rs.getObject("pes_fic") );
    		pessoa.setPesAtoslav( (java.lang.Boolean) rs.getObject("pes_atoslav") );
    		pessoa.setPesLogin( (java.lang.String) rs.getObject("pes_login") );
                pessoa.setPesSenha( (java.lang.String) rs.getObject("pes_senha") );
                pessoa.setPesAposentado((java.lang.String)rs.getObject("pes_aposentado") );
                pessoa.setPesAutonomo((java.lang.String)rs.getObject("pes_autonomo") );
                pessoa.setPesNaturalizado((java.lang.String)rs.getObject("pes_naturalizado") );
                pessoa.setPesCertificado((byte[]) rs.getObject("pes_certificado"));
    	}
        } catch( SQLException e ) {
            throw new SQLException(PessoaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return pessoa;
    }
    
    public Pessoa selectLogin(java.lang.String login) throws SQLException {
    	Pessoa pessoa = null;
        String sql = "SELECT pes_codigo, pes_nome, pes_nacionalidade, pes_data_nascto, " +
                     "pes_local_nascto, pes_loc_nasc_uf, pes_sexo, pes_est_civil, " +
                     "pes_reg_bens, pes_nome_conj, pes_profissao, pes_rg, pes_rg_dat_exp, " +
                     "pes_cpf, pes_doc_profissao, pes_pai, pes_mae, pes_end_cidade, pes_end_bairro, " +
                     "pes_end_uf, pes_end_cep, pes_end_nro, pes_complemento, pes_telefone1, " +
                     "pes_telefone2, pes_data_cadastro, pes_ult_atualizacao, func_codigo, " +
                     "pes_observacao, pes_sobrenome, pes_status, pes_rg_org_emis, pes_fic, " +
                     "pes_atoslav, pes_login, pes_senha, pes_autonomo, pes_naturalizado, pes_aposentado, " +
                     "pes_certificado FROM pessoa WHERE pes_login=?";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ps.setObject( ++idx, login );
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		pessoa = new Pessoa();
    		pessoa.setPesCodigo( (java.lang.Integer) rs.getObject("pes_codigo") );
    		pessoa.setPesNome( (java.lang.String) rs.getObject("pes_nome") );
    		pessoa.setPesNacionalidade( (java.lang.Integer) rs.getObject("pes_nacionalidade") );
    		pessoa.setPesDataNascto( (java.util.Date) rs.getObject("pes_data_nascto") );
    		pessoa.setPesLocalNascto( (java.lang.Integer) rs.getObject("pes_local_nascto") );
    		pessoa.setPesLocNascUf( (java.lang.Integer) rs.getObject("pes_loc_nasc_uf") );
    		pessoa.setPesSexo( (java.lang.Integer) rs.getObject("pes_sexo") );
    		pessoa.setPesEstCivil( (java.lang.Integer) rs.getObject("pes_est_civil") );
    		pessoa.setPesRegBens( (java.lang.Integer) rs.getObject("pes_reg_bens") );
    		pessoa.setPesNomeConj( (java.lang.String) rs.getObject("pes_nome_conj") );
    		pessoa.setPesProfissao( (java.lang.Integer) rs.getObject("pes_profissao") );
    		pessoa.setPesRg( (java.lang.String) rs.getObject("pes_rg") );
    		pessoa.setPesRgDatExp( (java.util.Date) rs.getObject("pes_rg_dat_exp") );
    		pessoa.setPesCpf( (java.lang.String) rs.getObject("pes_cpf") );
    		pessoa.setPesDocProfissao( (java.lang.String) rs.getObject("pes_doc_profissao") );
    		pessoa.setPesPai( (java.lang.String) rs.getObject("pes_pai") );
    		pessoa.setPesMae( (java.lang.String) rs.getObject("pes_mae") );
    		pessoa.setPesEndCidade( (java.lang.Integer) rs.getObject("pes_end_cidade") );
    		pessoa.setPesEndBairro( (java.lang.Integer) rs.getObject("pes_end_bairro") );
    		pessoa.setPesEndUf( (java.lang.Integer) rs.getObject("pes_end_uf") );
    		pessoa.setPesEndCep( (java.lang.String) rs.getObject("pes_end_cep") );
    		pessoa.setPesEndNro( (java.lang.Integer) rs.getObject("pes_end_nro") );
    		pessoa.setPesComplemento( (java.lang.String) rs.getObject("pes_complemento") );
    		pessoa.setPesTelefone1( (java.lang.String) rs.getObject("pes_telefone1") );
    		pessoa.setPesTelefone2( (java.lang.String) rs.getObject("pes_telefone2") );
    		pessoa.setPesDataCadastro( (java.util.Date) rs.getObject("pes_data_cadastro") );
    		pessoa.setPesUltAtualizacao( (java.util.Date) rs.getObject("pes_ult_atualizacao") );
    		pessoa.setFuncCodigo( (java.lang.Integer) rs.getObject("func_codigo") );
    		pessoa.setPesObservacao( (java.lang.String) rs.getObject("pes_observacao") );
    		pessoa.setPesSobrenome( (java.lang.String) rs.getObject("pes_sobrenome") );
    		pessoa.setPesStatus( (java.lang.Short) rs.getObject("pes_status") );
    		pessoa.setPesRgOrgEmis( (java.lang.Integer) rs.getObject("pes_rg_org_emis") );
    		pessoa.setPesFic( (java.lang.Boolean) rs.getObject("pes_fic") );
    		pessoa.setPesAtoslav( (java.lang.Boolean) rs.getObject("pes_atoslav") );
                pessoa.setPesLogin( (java.lang.String) rs.getObject("pes_login") );
                pessoa.setPesSenha( (java.lang.String) rs.getObject("pes_senha") );
                pessoa.setPesCertificado((byte[]) rs.getObject("pes_certificado"));
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(PessoaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return pessoa;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela pessoa
     */
    public java.util.List <Pessoa> getColecao() throws SQLException {
        Pessoa pessoa = null;
        String sql = "SELECT pes_codigo, pes_nome, pes_nacionalidade, pes_data_nascto, pes_local_nascto, pes_loc_nasc_uf, pes_sexo, pes_est_civil, pes_reg_bens, pes_nome_conj, pes_profissao, pes_rg, pes_rg_dat_exp, pes_cpf, pes_doc_profissao, pes_pai, pes_mae, pes_end_cidade, pes_end_bairro, pes_end_uf, pes_end_cep, pes_end_nro, pes_complemento, pes_telefone1, pes_telefone2, pes_data_cadastro, pes_ult_atualizacao, func_codigo, pes_observacao, pes_sobrenome, pes_status, pes_rg_org_emis, pes_fic, pes_atoslav, pes_login, pes_senha " +
                     "FROM pessoa ";
        PreparedStatement ps = null;
        java.util.ArrayList <Pessoa> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		pessoa = new Pessoa();
      		pessoa.setPesCodigo( (java.lang.Integer) rs.getObject("pes_codigo") );
    		      pessoa.setPesNome( (java.lang.String) rs.getObject("pes_nome") );
    		      pessoa.setPesNacionalidade( (java.lang.Integer) rs.getObject("pes_nacionalidade") );
    		      pessoa.setPesDataNascto( (java.util.Date) rs.getObject("pes_data_nascto") );
    		      pessoa.setPesLocalNascto( (java.lang.Integer) rs.getObject("pes_local_nascto") );
    		      pessoa.setPesLocNascUf( (java.lang.Integer) rs.getObject("pes_loc_nasc_uf") );
    		      pessoa.setPesSexo( (java.lang.Integer) rs.getObject("pes_sexo") );
    		      pessoa.setPesEstCivil( (java.lang.Integer) rs.getObject("pes_est_civil") );
    		      pessoa.setPesRegBens( (java.lang.Integer) rs.getObject("pes_reg_bens") );
    		      pessoa.setPesNomeConj( (java.lang.String) rs.getObject("pes_nome_conj") );
    		      pessoa.setPesProfissao( (java.lang.Integer) rs.getObject("pes_profissao") );
    		      pessoa.setPesRg( (java.lang.String) rs.getObject("pes_rg") );
    		      pessoa.setPesRgDatExp( (java.util.Date) rs.getObject("pes_rg_dat_exp") );
    		      pessoa.setPesCpf( (java.lang.String) rs.getObject("pes_cpf") );
    		      pessoa.setPesDocProfissao( (java.lang.String) rs.getObject("pes_doc_profissao") );
    		      pessoa.setPesPai( (java.lang.String) rs.getObject("pes_pai") );
    		      pessoa.setPesMae( (java.lang.String) rs.getObject("pes_mae") );
    		      pessoa.setPesEndCidade( (java.lang.Integer) rs.getObject("pes_end_cidade") );
    		      pessoa.setPesEndBairro( (java.lang.Integer) rs.getObject("pes_end_bairro") );
    		      pessoa.setPesEndUf( (java.lang.Integer) rs.getObject("pes_end_uf") );
    		      pessoa.setPesEndCep( (java.lang.String) rs.getObject("pes_end_cep") );
    		      pessoa.setPesEndNro( (java.lang.Integer) rs.getObject("pes_end_nro") );
    		      pessoa.setPesComplemento( (java.lang.String) rs.getObject("pes_complemento") );
    		      pessoa.setPesTelefone1( (java.lang.String) rs.getObject("pes_telefone1") );
    		      pessoa.setPesTelefone2( (java.lang.String) rs.getObject("pes_telefone2") );
    		      pessoa.setPesDataCadastro( (java.util.Date) rs.getObject("pes_data_cadastro") );
    		      pessoa.setPesUltAtualizacao( (java.util.Date) rs.getObject("pes_ult_atualizacao") );
    		      pessoa.setFuncCodigo( (java.lang.Integer) rs.getObject("func_codigo") );
    		      pessoa.setPesObservacao( (java.lang.String) rs.getObject("pes_observacao") );
    		      pessoa.setPesSobrenome( (java.lang.String) rs.getObject("pes_sobrenome") );
    		      pessoa.setPesStatus( (java.lang.Short) rs.getObject("pes_status") );
    		      pessoa.setPesRgOrgEmis( (java.lang.Integer) rs.getObject("pes_rg_org_emis") );
    		      pessoa.setPesFic( (java.lang.Boolean) rs.getObject("pes_fic") );
    		      pessoa.setPesAtoslav( (java.lang.Boolean) rs.getObject("pes_atoslav") );
                      pessoa.setPesLogin( (java.lang.String) rs.getObject("pes_login") );
                      pessoa.setPesSenha( (java.lang.String) rs.getObject("pes_senha") );
    		      
                  colec.add( pessoa );
            }
        } catch( SQLException e ) {
            throw new SQLException(PessoaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
    
    
    /**
     * getColecao
     * retorna todos os registros da tabela pessoa
     */
    public java.util.List <Pessoa> getPessoasLikeNome(String nome ) throws SQLException {
        Pessoa pessoa = null;
        String sql = "SELECT pes_codigo, pes_nome, pes_nacionalidade, pes_data_nascto, pes_local_nascto, pes_loc_nasc_uf, pes_sexo, pes_est_civil, pes_reg_bens, pes_nome_conj, pes_profissao, pes_rg, pes_rg_dat_exp, pes_cpf, pes_doc_profissao, pes_pai, pes_mae, pes_end_cidade, pes_end_bairro, pes_end_uf, pes_end_cep, pes_end_nro, pes_complemento, pes_telefone1, pes_telefone2, pes_data_cadastro, pes_ult_atualizacao, func_codigo, pes_observacao, pes_sobrenome, pes_status, pes_rg_org_emis, pes_fic, pes_atoslav, pes_login, pes_senha " +
                     "FROM pessoa where Upper(pes_nome) like Upper(?)  and pes_fic = true order by pes_nome ";
        PreparedStatement ps = null;
        java.util.ArrayList <Pessoa> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            int idx = 0;
            
            ps.setObject( ++idx, nome );
            
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		pessoa = new Pessoa();
      		pessoa.setPesCodigo( (java.lang.Integer) rs.getObject("pes_codigo") );
    		      pessoa.setPesNome( (java.lang.String) rs.getObject("pes_nome") );
    		      pessoa.setPesNacionalidade( (java.lang.Integer) rs.getObject("pes_nacionalidade") );
    		      pessoa.setPesDataNascto( (java.util.Date) rs.getObject("pes_data_nascto") );
    		      pessoa.setPesLocalNascto( (java.lang.Integer) rs.getObject("pes_local_nascto") );
    		      pessoa.setPesLocNascUf( (java.lang.Integer) rs.getObject("pes_loc_nasc_uf") );
    		      pessoa.setPesSexo( (java.lang.Integer) rs.getObject("pes_sexo") );
    		      pessoa.setPesEstCivil( (java.lang.Integer) rs.getObject("pes_est_civil") );
    		      pessoa.setPesRegBens( (java.lang.Integer) rs.getObject("pes_reg_bens") );
    		      pessoa.setPesNomeConj( (java.lang.String) rs.getObject("pes_nome_conj") );
    		      pessoa.setPesProfissao( (java.lang.Integer) rs.getObject("pes_profissao") );
    		      pessoa.setPesRg( (java.lang.String) rs.getObject("pes_rg") );
    		      pessoa.setPesRgDatExp( (java.util.Date) rs.getObject("pes_rg_dat_exp") );
    		      pessoa.setPesCpf( (java.lang.String) rs.getObject("pes_cpf") );
    		      pessoa.setPesDocProfissao( (java.lang.String) rs.getObject("pes_doc_profissao") );
    		      pessoa.setPesPai( (java.lang.String) rs.getObject("pes_pai") );
    		      pessoa.setPesMae( (java.lang.String) rs.getObject("pes_mae") );
    		      pessoa.setPesEndCidade( (java.lang.Integer) rs.getObject("pes_end_cidade") );
    		      pessoa.setPesEndBairro( (java.lang.Integer) rs.getObject("pes_end_bairro") );
    		      pessoa.setPesEndUf( (java.lang.Integer) rs.getObject("pes_end_uf") );
    		      pessoa.setPesEndCep( (java.lang.String) rs.getObject("pes_end_cep") );
    		      pessoa.setPesEndNro( (java.lang.Integer) rs.getObject("pes_end_nro") );
    		      pessoa.setPesComplemento( (java.lang.String) rs.getObject("pes_complemento") );
    		      pessoa.setPesTelefone1( (java.lang.String) rs.getObject("pes_telefone1") );
    		      pessoa.setPesTelefone2( (java.lang.String) rs.getObject("pes_telefone2") );
    		      pessoa.setPesDataCadastro( (java.util.Date) rs.getObject("pes_data_cadastro") );
    		      pessoa.setPesUltAtualizacao( (java.util.Date) rs.getObject("pes_ult_atualizacao") );
    		      pessoa.setFuncCodigo( (java.lang.Integer) rs.getObject("func_codigo") );
    		      pessoa.setPesObservacao( (java.lang.String) rs.getObject("pes_observacao") );
    		      pessoa.setPesSobrenome( (java.lang.String) rs.getObject("pes_sobrenome") );
    		      pessoa.setPesStatus( (java.lang.Short) rs.getObject("pes_status") );
    		      pessoa.setPesRgOrgEmis( (java.lang.Integer) rs.getObject("pes_rg_org_emis") );
    		      pessoa.setPesFic( (java.lang.Boolean) rs.getObject("pes_fic") );
    		      pessoa.setPesAtoslav( (java.lang.Boolean) rs.getObject("pes_atoslav") );
                      pessoa.setPesLogin( (java.lang.String) rs.getObject("pes_login") );
                      pessoa.setPesSenha( (java.lang.String) rs.getObject("pes_senha") );
    		      
                  colec.add( pessoa );
            }
        } catch( SQLException e ) {
            throw new SQLException(PessoaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
    
    
    /**
     * getColecao
     * retorna todos os registros da tabela pessoa
     */
    public java.util.List <Pessoa> getPessoasLikeCpf(String cpf ) throws SQLException {
        Pessoa pessoa = null;
        String sql = "SELECT pes_codigo, pes_nome, pes_nacionalidade, pes_data_nascto, " +
                     "pes_local_nascto, pes_loc_nasc_uf, pes_sexo, pes_est_civil, pes_reg_bens, " +
                     "pes_nome_conj, pes_profissao, pes_rg, pes_rg_dat_exp, pes_cpf, " +
                     "pes_doc_profissao, pes_pai, pes_mae, pes_end_cidade, pes_end_bairro, " +
                     "pes_end_uf, pes_end_cep, pes_end_nro, pes_complemento, pes_telefone1, " +
                     "pes_telefone2, pes_data_cadastro, pes_ult_atualizacao, func_codigo, " +
                     "pes_observacao, pes_sobrenome, pes_status, pes_rg_org_emis, pes_fic, " +
                     "pes_atoslav, pes_login, pes_senha, pes_autonomo, pes_naturalizado, pes_aposentado " +
                     "FROM pessoa where Upper(pes_cpf) like Upper(?) and pes_fic = true order by pes_nome ";
        PreparedStatement ps = null;
        java.util.ArrayList <Pessoa> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            int idx = 0;
            
            ps.setObject( ++idx, cpf );
            
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		pessoa = new Pessoa();
      		pessoa.setPesCodigo( (java.lang.Integer) rs.getObject("pes_codigo") );
    		      pessoa.setPesNome( (java.lang.String) rs.getObject("pes_nome") );
    		      pessoa.setPesNacionalidade( (java.lang.Integer) rs.getObject("pes_nacionalidade") );
    		      pessoa.setPesDataNascto( (java.util.Date) rs.getObject("pes_data_nascto") );
    		      pessoa.setPesLocalNascto( (java.lang.Integer) rs.getObject("pes_local_nascto") );
    		      pessoa.setPesLocNascUf( (java.lang.Integer) rs.getObject("pes_loc_nasc_uf") );
    		      pessoa.setPesSexo( (java.lang.Integer) rs.getObject("pes_sexo") );
    		      pessoa.setPesEstCivil( (java.lang.Integer) rs.getObject("pes_est_civil") );
    		      pessoa.setPesRegBens( (java.lang.Integer) rs.getObject("pes_reg_bens") );
    		      pessoa.setPesNomeConj( (java.lang.String) rs.getObject("pes_nome_conj") );
    		      pessoa.setPesProfissao( (java.lang.Integer) rs.getObject("pes_profissao") );
    		      pessoa.setPesRg( (java.lang.String) rs.getObject("pes_rg") );
    		      pessoa.setPesRgDatExp( (java.util.Date) rs.getObject("pes_rg_dat_exp") );
    		      pessoa.setPesCpf( (java.lang.String) rs.getObject("pes_cpf") );
    		      pessoa.setPesDocProfissao( (java.lang.String) rs.getObject("pes_doc_profissao") );
    		      pessoa.setPesPai( (java.lang.String) rs.getObject("pes_pai") );
    		      pessoa.setPesMae( (java.lang.String) rs.getObject("pes_mae") );
    		      pessoa.setPesEndCidade( (java.lang.Integer) rs.getObject("pes_end_cidade") );
    		      pessoa.setPesEndBairro( (java.lang.Integer) rs.getObject("pes_end_bairro") );
    		      pessoa.setPesEndUf( (java.lang.Integer) rs.getObject("pes_end_uf") );
    		      pessoa.setPesEndCep( (java.lang.String) rs.getObject("pes_end_cep") );
    		      pessoa.setPesEndNro( (java.lang.Integer) rs.getObject("pes_end_nro") );
    		      pessoa.setPesComplemento( (java.lang.String) rs.getObject("pes_complemento") );
    		      pessoa.setPesTelefone1( (java.lang.String) rs.getObject("pes_telefone1") );
    		      pessoa.setPesTelefone2( (java.lang.String) rs.getObject("pes_telefone2") );
    		      pessoa.setPesDataCadastro( (java.util.Date) rs.getObject("pes_data_cadastro") );
    		      pessoa.setPesUltAtualizacao( (java.util.Date) rs.getObject("pes_ult_atualizacao") );
    		      pessoa.setFuncCodigo( (java.lang.Integer) rs.getObject("func_codigo") );
    		      pessoa.setPesObservacao( (java.lang.String) rs.getObject("pes_observacao") );
    		      pessoa.setPesSobrenome( (java.lang.String) rs.getObject("pes_sobrenome") );
    		      pessoa.setPesStatus( (java.lang.Short) rs.getObject("pes_status") );
    		      pessoa.setPesRgOrgEmis( (java.lang.Integer) rs.getObject("pes_rg_org_emis") );
    		      pessoa.setPesFic( (java.lang.Boolean) rs.getObject("pes_fic") );
    		      pessoa.setPesAtoslav( (java.lang.Boolean) rs.getObject("pes_atoslav") );
                      pessoa.setPesLogin( (java.lang.String) rs.getObject("pes_login") );
                      pessoa.setPesSenha( (java.lang.String) rs.getObject("pes_senha") );
                      pessoa.setPesAposentado((java.lang.String) rs.getObject("pes_aposentado"));
                      pessoa.setPesAutonomo((java.lang.String) rs.getObject("pes_autonomo"));
                      pessoa.setPesNaturalizado((java.lang.String) rs.getObject("pes_naturalizado"));
    		      
                  colec.add( pessoa );
            }
        } catch( SQLException e ) {
            throw new SQLException(PessoaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
    
    
}
