
package br.com.tabelionatomessias.dao.cart;
/**
 * Sistema: Notarium
 * 
 * Arquivo: SinPubDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela sin_pub
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class SinPubDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public SinPubDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(SinPub sinPub) throws SQLException {
        String sql = "INSERT INTO sin_pub " +
                     "(sinpub_codigo, sinpub_nome, crt_codigo, sinpub_funcao, sinpub_status, sinpub_cpf, sinpub_rg, sinpub_data_cadastro, sinpub_ult_atualizacao, func_codigo, sinpub_envio_cartao, sinpub_data_validade) " +
                     "VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, sinPub.getSinpubCodigo() );

    	ps.setObject( ++idx, sinPub.getSinpubNome() );

    	ps.setObject( ++idx, sinPub.getCrtCodigo() );

    	ps.setObject( ++idx, sinPub.getSinpubFuncao() );

    	ps.setObject( ++idx, sinPub.getSinpubStatus() );

    	ps.setObject( ++idx, sinPub.getSinpubCpf() );

    	ps.setObject( ++idx, sinPub.getSinpubRg() );

    	ps.setObject( ++idx, sinPub.getSinpubDataCadastro() );

    	ps.setObject( ++idx, sinPub.getSinpubUltAtualizacao() );

    	ps.setObject( ++idx, sinPub.getFuncCodigo() );

    	ps.setObject( ++idx, sinPub.getSinpubEnvioCartao() );

    	ps.setObject( ++idx, sinPub.getSinpubDataValidade() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(SinPubDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(SinPub sinPub) throws SQLException {
        String sql = "UPDATE sin_pub SET " +
                     "sinpub_codigo=?, sinpub_nome=?, crt_codigo=?, sinpub_funcao=?, sinpub_status=?, sinpub_cpf=?, sinpub_rg=?, sinpub_data_cadastro=?, sinpub_ult_atualizacao=?, func_codigo=?, sinpub_envio_cartao=?, sinpub_data_validade=? " +
                     
                     "WHERE sinpub_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, sinPub.getSinpubCodigo() );

    	ps.setObject( ++idx, sinPub.getSinpubNome() );

    	ps.setObject( ++idx, sinPub.getCrtCodigo() );

    	ps.setObject( ++idx, sinPub.getSinpubFuncao() );

    	ps.setObject( ++idx, sinPub.getSinpubStatus() );

    	ps.setObject( ++idx, sinPub.getSinpubCpf() );

    	ps.setObject( ++idx, sinPub.getSinpubRg() );

    	ps.setObject( ++idx, sinPub.getSinpubDataCadastro() );

    	ps.setObject( ++idx, sinPub.getSinpubUltAtualizacao() );

    	ps.setObject( ++idx, sinPub.getFuncCodigo() );

    	ps.setObject( ++idx, sinPub.getSinpubEnvioCartao() );

    	ps.setObject( ++idx, sinPub.getSinpubDataValidade() );

    	ps.setObject( ++idx, sinPub.getSinpubCodigo() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(SinPubDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(SinPub sinPub) throws SQLException {
        String sql = "DELETE FROM sin_pub " +
                     
                     "WHERE sinpub_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, sinPub.getSinpubCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(SinPubDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE sinpub_codigo=?";

     */
    public SinPub selectPK(java.lang.Integer sinpubCodigo) throws SQLException {
    	SinPub sinPub = null;
        String sql = "SELECT sinpub_codigo, sinpub_nome, crt_codigo, sinpub_funcao, sinpub_status, sinpub_cpf, sinpub_rg, sinpub_data_cadastro, sinpub_ult_atualizacao, func_codigo, sinpub_envio_cartao, sinpub_data_validade " +
                     "FROM sin_pub " +
                     
                     "WHERE sinpub_codigo=?";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ps.setObject( ++idx, sinpubCodigo );
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		sinPub = new SinPub();
    		sinPub.setSinpubCodigo( (java.lang.Integer) rs.getObject("sinpub_codigo") );
    		sinPub.setSinpubNome( (java.lang.String) rs.getObject("sinpub_nome") );
    		sinPub.setCrtCodigo( (java.lang.Integer) rs.getObject("crt_codigo") );
    		sinPub.setSinpubFuncao( (java.lang.Integer) rs.getObject("sinpub_funcao") );
    		sinPub.setSinpubStatus( (java.lang.Integer) rs.getObject("sinpub_status") );
    		sinPub.setSinpubCpf( (java.lang.String) rs.getObject("sinpub_cpf") );
    		sinPub.setSinpubRg( (java.lang.String) rs.getObject("sinpub_rg") );
    		sinPub.setSinpubDataCadastro( (java.sql.Date) rs.getObject("sinpub_data_cadastro") );
    		sinPub.setSinpubUltAtualizacao( (java.sql.Date) rs.getObject("sinpub_ult_atualizacao") );
    		sinPub.setFuncCodigo( (java.lang.Integer) rs.getObject("func_codigo") );
    		sinPub.setSinpubEnvioCartao( (java.sql.Date) rs.getObject("sinpub_envio_cartao") );
    		sinPub.setSinpubDataValidade( (java.sql.Date) rs.getObject("sinpub_data_validade") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(SinPubDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return sinPub;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela sin_pub
     */
    public java.util.List <SinPub> getColecao() throws SQLException {
        SinPub sinPub = null;
        String sql = "SELECT sinpub_codigo, sinpub_nome, crt_codigo, sinpub_funcao, sinpub_status, sinpub_cpf, sinpub_rg, sinpub_data_cadastro, sinpub_ult_atualizacao, func_codigo, sinpub_envio_cartao, sinpub_data_validade " +
                     "FROM sin_pub ";
        PreparedStatement ps = null;
        java.util.ArrayList <SinPub> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		sinPub = new SinPub();
      		sinPub.setSinpubCodigo( (java.lang.Integer) rs.getObject("sinpub_codigo") );
    		      sinPub.setSinpubNome( (java.lang.String) rs.getObject("sinpub_nome") );
    		      sinPub.setCrtCodigo( (java.lang.Integer) rs.getObject("crt_codigo") );
    		      sinPub.setSinpubFuncao( (java.lang.Integer) rs.getObject("sinpub_funcao") );
    		      sinPub.setSinpubStatus( (java.lang.Integer) rs.getObject("sinpub_status") );
    		      sinPub.setSinpubCpf( (java.lang.String) rs.getObject("sinpub_cpf") );
    		      sinPub.setSinpubRg( (java.lang.String) rs.getObject("sinpub_rg") );
    		      sinPub.setSinpubDataCadastro( (java.sql.Date) rs.getObject("sinpub_data_cadastro") );
    		      sinPub.setSinpubUltAtualizacao( (java.sql.Date) rs.getObject("sinpub_ult_atualizacao") );
    		      sinPub.setFuncCodigo( (java.lang.Integer) rs.getObject("func_codigo") );
    		      sinPub.setSinpubEnvioCartao( (java.sql.Date) rs.getObject("sinpub_envio_cartao") );
    		      sinPub.setSinpubDataValidade( (java.sql.Date) rs.getObject("sinpub_data_validade") );
    		      
                  colec.add( sinPub );
            }
        } catch( SQLException e ) {
            throw new SQLException(SinPubDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
    
     /**
     * SelectSinPub
     * retorna todos os registros da tabela sin_pub filtrando de acordo com o tipo de argumento informado.
     */
    public java.util.List <SinPub> SelectSinPub(java.lang.String argumento, java.lang.String tipo) throws SQLException {
        SinPub sinPub = null;
        String sql = "";
        if (tipo.equals("0")) {
        sql = "SELECT sinpub_codigo, " +
                     "sinpub_nome, sinpub.crt_codigo, sinpub.sinpub_funcao, sinpub.sinpub_status, sinpub.sinpub_cpf, " +
                     "sinpub.sinpub_rg, sinpub.sinpub_data_cadastro, sinpub.sinpub_ult_atualizacao, sinpub.func_codigo, " +
                     "sinpub.sinpub_envio_cartao, sinpub.sinpub_data_validade " +
                     "FROM sin_pub sinpub, cartorio cart where sinpub.crt_codigo = cart.crt_codigo and sinpub.sinpub_funcao = 1 and cart.crt_nome like ? ";
        } 
        if (tipo.equals("1")) {
          sql = "select sinpub.sinpub_codigo,  sinpub.sinpub_nome,   sinpub.crt_codigo,   sinpub.sinpub_funcao,   sinpub.sinpub_status,   sinpub.sinpub_cpf,  sinpub.sinpub_rg,   sinpub.sinpub_data_cadastro,   sinpub.sinpub_ult_atualizacao,   sinpub.func_codigo,  sinpub.sinpub_envio_cartao,   sinpub.sinpub_data_validade from sin_pub sinpub,cartorio cart,localidades loc where   Upper(loc.ceploc_nome) like Upper(?) and   cart.ceploc_codigo = loc.ceploc_codigo and   sinpub.crt_codigo = cart.crt_codigo and   sinpub.sinpub_funcao = 1 order by   crt_nome, ceploc_nome, sinpub_nome  ";
        }
        if (tipo.equals("2")) {
          sql = "select sinpub.sinpub_codigo,  sinpub.sinpub_nome,   sinpub.crt_codigo,   sinpub.sinpub_funcao,   sinpub.sinpub_status,   sinpub.sinpub_cpf,  sinpub.sinpub_rg,   sinpub.sinpub_data_cadastro,   sinpub.sinpub_ult_atualizacao,   sinpub.func_codigo,  sinpub.sinpub_envio_cartao,   sinpub.sinpub_data_validade from sin_pub sinpub,cartorio cart,localidades loc where  sinpub.sinpub_nome like ? and sinpub.sinpub_funcao = 1 and cart.crt_codigo = sinpub.crt_codigo and loc.ceploc_codigo = cart.ceploc_codigo order by crt_nome,ceploc_nome,sinpub_nome ";
        }
        if (tipo.equals("3")) {
          sql = "select sinpub.sinpub_codigo,  sinpub.sinpub_nome,   sinpub.crt_codigo,   sinpub.sinpub_funcao,   sinpub.sinpub_status,   sinpub.sinpub_cpf,  sinpub.sinpub_rg,   sinpub.sinpub_data_cadastro,   sinpub.sinpub_ult_atualizacao,   sinpub.func_codigo,  sinpub.sinpub_envio_cartao,   sinpub.sinpub_data_validade from sin_pub sinpub,cartorio cart,localidades loc where  sinpub.sinpub_nome like ? and sinpub.sinpub_funcao = 3 and cart.crt_codigo = sinpub.crt_codigo and loc.ceploc_codigo = cart.ceploc_codigo order by crt_nome,ceploc_nome,sinpub_nome ";
        }
        
        
        PreparedStatement ps = null;
        java.util.ArrayList <SinPub> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            int idx = 0;
            ps.setObject( ++idx, argumento );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		sinPub = new SinPub();
      		sinPub.setSinpubCodigo( (java.lang.Integer) rs.getObject("sinpub_codigo") );
    		      sinPub.setSinpubNome( (java.lang.String) rs.getObject("sinpub_nome") );
    		      sinPub.setCrtCodigo( (java.lang.Integer) rs.getObject("crt_codigo") );
    		      sinPub.setSinpubFuncao( (java.lang.Integer) rs.getObject("sinpub_funcao") );
    		      sinPub.setSinpubStatus( (java.lang.Integer) rs.getObject("sinpub_status") );
    		      sinPub.setSinpubCpf( (java.lang.String) rs.getObject("sinpub_cpf") );
    		      sinPub.setSinpubRg( (java.lang.String) rs.getObject("sinpub_rg") );
    		      sinPub.setSinpubDataCadastro( (java.sql.Date) rs.getObject("sinpub_data_cadastro") );
    		      sinPub.setSinpubUltAtualizacao( (java.sql.Date) rs.getObject("sinpub_ult_atualizacao") );
    		      sinPub.setFuncCodigo( (java.lang.Integer) rs.getObject("func_codigo") );
    		      sinPub.setSinpubEnvioCartao( (java.sql.Date) rs.getObject("sinpub_envio_cartao") );
    		      sinPub.setSinpubDataValidade( (java.sql.Date) rs.getObject("sinpub_data_validade") );
                      
    		      
                  colec.add( sinPub );
            }
        } catch( SQLException e ) {
            throw new SQLException(SinPubDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
    
     /**
     * getSinPubCartorio
     * retorna todos os registros da tabela sin_pub para o cdigo do Cartrio
     */
    public java.util.List <SinPub> getSinPubCartorio(java.lang.Integer cartorio) throws SQLException {
        SinPub sinPub = null;
        String sql = "";
        sql = "select sinpub.* from sin_pub sinpub,cartorio cart where cart.crt_codigo = sinpub.crt_codigo and cart.crt_codigo = ? ";
        
        PreparedStatement ps = null;
        java.util.ArrayList <SinPub> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            int idx = 0;
            ps.setObject( ++idx, cartorio );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		sinPub = new SinPub();
      		sinPub.setSinpubCodigo( (java.lang.Integer) rs.getObject("sinpub_codigo") );
    		      sinPub.setSinpubNome( (java.lang.String) rs.getObject("sinpub_nome") );
    		      sinPub.setCrtCodigo( (java.lang.Integer) rs.getObject("crt_codigo") );
    		      sinPub.setSinpubFuncao( (java.lang.Integer) rs.getObject("sinpub_funcao") );
    		      sinPub.setSinpubStatus( (java.lang.Integer) rs.getObject("sinpub_status") );
    		      sinPub.setSinpubCpf( (java.lang.String) rs.getObject("sinpub_cpf") );
    		      sinPub.setSinpubRg( (java.lang.String) rs.getObject("sinpub_rg") );
    		      sinPub.setSinpubDataCadastro( (java.sql.Date) rs.getObject("sinpub_data_cadastro") );
    		      sinPub.setSinpubUltAtualizacao( (java.sql.Date) rs.getObject("sinpub_ult_atualizacao") );
    		      sinPub.setFuncCodigo( (java.lang.Integer) rs.getObject("func_codigo") );
    		      sinPub.setSinpubEnvioCartao( (java.sql.Date) rs.getObject("sinpub_envio_cartao") );
    		      sinPub.setSinpubDataValidade( (java.sql.Date) rs.getObject("sinpub_data_validade") );
                      
    		      
                  colec.add( sinPub );
            }
        } catch( SQLException e ) {
            throw new SQLException(SinPubDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }

    
}
