package br.com.tabelionatomessias.dao.cart;
/**
 * Sistema: Notarium
 * 
 * Arquivo: TipatosDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela tipatos
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class TipatosDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public TipatosDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(Tipatos tipatos) throws SQLException {
        String sql = "INSERT INTO tipatos " +
                     "(tipato_codigo, tipato_descricao, tipato_funccad, tipato_datcad) " +
                     "VALUES (?, ?, ?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, tipatos.getTipatoCodigo() );

    	ps.setObject( ++idx, tipatos.getTipatoDescricao() );

    	ps.setObject( ++idx, tipatos.getTipatoFunccad() );

    	ps.setObject( ++idx, tipatos.getTipatoDatcad() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(TipatosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(Tipatos tipatos) throws SQLException {
        String sql = "UPDATE tipatos SET " +
                     "tipato_codigo=?, tipato_descricao=?, tipato_funccad=?, tipato_datcad=? " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, tipatos.getTipatoCodigo() );

    	ps.setObject( ++idx, tipatos.getTipatoDescricao() );

    	ps.setObject( ++idx, tipatos.getTipatoFunccad() );

    	ps.setObject( ++idx, tipatos.getTipatoDatcad() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(TipatosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(Tipatos tipatos) throws SQLException {
        String sql = "DELETE FROM tipatos " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(TipatosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE ";

     */
    public Tipatos selectPK(java.lang.Integer codigo) throws SQLException {
    	Tipatos tipatos = null;
        String sql = "SELECT tipato_codigo, tipato_descricao, tipato_funccad, tipato_datcad " +
                     "FROM tipatos " +
                     
                     "WHERE tipato_codigo = ?";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	ps.setObject( ++idx, codigo );
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		tipatos = new Tipatos();
    		tipatos.setTipatoCodigo( (java.lang.Integer) rs.getObject("tipato_codigo") );
    		tipatos.setTipatoDescricao( (java.lang.String) rs.getObject("tipato_descricao") );
    		tipatos.setTipatoFunccad( (java.lang.Integer) rs.getObject("tipato_funccad") );
    		tipatos.setTipatoDatcad( (java.sql.Date) rs.getObject("tipato_datcad") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(TipatosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return tipatos;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela tipatos
     */
    public java.util.List <Tipatos> getColecao() throws SQLException {
        Tipatos tipatos = null;
        String sql = "SELECT tipato_codigo, tipato_descricao, tipato_funccad, tipato_datcad " +
                     "FROM tipatos ";
        PreparedStatement ps = null;
        java.util.ArrayList <Tipatos> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		tipatos = new Tipatos();
      		tipatos.setTipatoCodigo( (java.lang.Integer) rs.getObject("tipato_codigo") );
    		      tipatos.setTipatoDescricao( (java.lang.String) rs.getObject("tipato_descricao") );
    		      tipatos.setTipatoFunccad( (java.lang.Integer) rs.getObject("tipato_funccad") );
    		      tipatos.setTipatoDatcad( (java.sql.Date) rs.getObject("tipato_datcad") );
    		      
                  colec.add( tipatos );
            }
        } catch( SQLException e ) {
            throw new SQLException(TipatosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
}
