
package br.com.tabelionatomessias.dao.cart;
/**
 * Sistema: Notarium
 * 
 * Arquivo: TiposDeLogradourosDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela tipos_de_logradouros
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class TiposDeLogradourosDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public TiposDeLogradourosDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(TiposDeLogradouros tiposDeLogradouros) throws SQLException {
        String sql = "INSERT INTO tipos_de_logradouros " +
                     "(ceptip_codigo, ceptip_log, ceptip_nome, ceptip_abrev) " +
                     "VALUES (?, ?, ?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, tiposDeLogradouros.getCeptipCodigo() );

    	ps.setObject( ++idx, tiposDeLogradouros.getCeptipLog() );

    	ps.setObject( ++idx, tiposDeLogradouros.getCeptipNome() );

    	ps.setObject( ++idx, tiposDeLogradouros.getCeptipAbrev() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(TiposDeLogradourosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(TiposDeLogradouros tiposDeLogradouros) throws SQLException {
        String sql = "UPDATE tipos_de_logradouros SET " +
                     "ceptip_codigo=?, ceptip_log=?, ceptip_nome=?, ceptip_abrev=? " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, tiposDeLogradouros.getCeptipCodigo() );

    	ps.setObject( ++idx, tiposDeLogradouros.getCeptipLog() );

    	ps.setObject( ++idx, tiposDeLogradouros.getCeptipNome() );

    	ps.setObject( ++idx, tiposDeLogradouros.getCeptipAbrev() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(TiposDeLogradourosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(TiposDeLogradouros tiposDeLogradouros) throws SQLException {
        String sql = "DELETE FROM tipos_de_logradouros " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(TiposDeLogradourosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE ";

     */
    public TiposDeLogradouros selectPK(java.lang.String codigo) throws SQLException {
    	TiposDeLogradouros tiposDeLogradouros = null;
        String sql = "SELECT ceptip_codigo, ceptip_log, ceptip_nome, ceptip_abrev " +
                     "FROM tipos_de_logradouros " +                     
                     "WHERE ceptip_codigo = ? ";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	ps.setObject(++idx, codigo);
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		tiposDeLogradouros = new TiposDeLogradouros();
    		tiposDeLogradouros.setCeptipCodigo( (java.lang.String) rs.getObject("ceptip_codigo") );
    		tiposDeLogradouros.setCeptipLog( (java.lang.Integer) rs.getObject("ceptip_log") );
    		tiposDeLogradouros.setCeptipNome( (java.lang.String) rs.getObject("ceptip_nome") );
    		tiposDeLogradouros.setCeptipAbrev( (java.lang.String) rs.getObject("ceptip_abrev") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(TiposDeLogradourosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return tiposDeLogradouros;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela tipos_de_logradouros
     */
    public java.util.List <TiposDeLogradouros> getColecao() throws SQLException {
        TiposDeLogradouros tiposDeLogradouros = null;
        String sql = "SELECT ceptip_codigo, ceptip_log, ceptip_nome, ceptip_abrev " +
                     "FROM tipos_de_logradouros ";
        PreparedStatement ps = null;
        java.util.ArrayList <TiposDeLogradouros> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		tiposDeLogradouros = new TiposDeLogradouros();
      		tiposDeLogradouros.setCeptipCodigo( (java.lang.String) rs.getObject("ceptip_codigo") );
    		      tiposDeLogradouros.setCeptipLog( (java.lang.Integer) rs.getObject("ceptip_log") );
    		      tiposDeLogradouros.setCeptipNome( (java.lang.String) rs.getObject("ceptip_nome") );
    		      tiposDeLogradouros.setCeptipAbrev( (java.lang.String) rs.getObject("ceptip_abrev") );
    		      
                  colec.add( tiposDeLogradouros );
            }
        } catch( SQLException e ) {
            throw new SQLException(TiposDeLogradourosDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
}
