
package br.com.tabelionatomessias.dao.web;
/**
 * Sistema: Notarium
 * 
 * Arquivo: CertidaoPublicaDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;
import java.util.Date;

/**
 * Classe que implementa o padro DAO da tabela certidaopublica
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class CertidaoPublicaDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public CertidaoPublicaDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(CertidaoPublica certidaoPublica) throws SQLException {
        String sql = "INSERT INTO web.certidaopublica (certpub_arquivo, certpub_data, " +
                     "certpub_verificador) VALUES (?, now(), ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, certidaoPublica.getCertpubArquivo());
        ps.setObject( ++idx, certidaoPublica.getCertpubVerificador());

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(CertidaoPublicaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(CertidaoPublica certidaoPublica) throws SQLException {
        String sql = "UPDATE certidaopublica SET certpub_arquivo=?, certpub_data=?, " +
                     "certpub_verificador=? WHERE certpub_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, certidaoPublica.getCertpubArquivo() );
        ps.setObject( ++idx, certidaoPublica.getCertpubData() );
        ps.setObject( ++idx, certidaoPublica.getCertpubVerificador() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(CertidaoPublicaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(CertidaoPublica certidaoPublica) throws SQLException {
        String sql = "DELETE FROM certidaopublica WHERE certpub_codigo=?" ;

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, certidaoPublica.getCertpubCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(CertidaoPublicaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     */
    public CertidaoPublica selectPK(java.lang.Integer certpubCodigo) throws SQLException {
    	CertidaoPublica certidaoPublica = null;
        String sql = "SELECT certpub_codigo, certpub_arquivo, certpub_data, certpub_verificador " +
                     "FROM certidaopublica WHERE certpub_codigo=?";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ps.setObject( ++idx, certpubCodigo );
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		certidaoPublica = new CertidaoPublica();
    		certidaoPublica.setCertpubCodigo((Integer) rs.getObject("certpub_codigo"));
                certidaoPublica.setCertpubArquivo((byte[]) rs.getObject("certpub_arquivo"));
                certidaoPublica.setCertpubData((Date) rs.getObject("certpub_data"));
                certidaoPublica.setCertpubVerificador((String) rs.getObject("certpub_verificador"));
    	}
        } catch( SQLException e ) {
            throw new SQLException(CertidaoPublicaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return certidaoPublica;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela certidaopublica
     */
    public java.util.List <CertidaoPublica> getColecao() throws SQLException {
        CertidaoPublica certidaoPublica = null;
        String sql = "SELECT certpub_codigo, certpub_arquivo, certpub_data, certpub_verificador " +
                     "FROM certidaopublica ";
        PreparedStatement ps = null;
        java.util.ArrayList <CertidaoPublica> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		certidaoPublica = new CertidaoPublica();
    		certidaoPublica.setCertpubCodigo((Integer) rs.getObject("certpub_codigo"));
                certidaoPublica.setCertpubArquivo((byte[]) rs.getObject("certpub_arquivo"));
                certidaoPublica.setCertpubData((Date) rs.getObject("certpub_data"));
                certidaoPublica.setCertpubVerificador((String) rs.getObject("certpub_verificador"));    		      
                colec.add( certidaoPublica );
            }
        } catch( SQLException e ) {
            throw new SQLException(CertidaoPublicaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
}
