
package br.com.tabelionatomessias.dao.web;
/**
 * Sistema: Notarium
 * 
 * Arquivo: DetalheservicoDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;
import java.sql.Timestamp;

/**
 * Classe que implementa o padro DAO da tabela detalheservico
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class DetalheservicoDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public DetalheservicoDAO(Connection conn) {
        this.conn = conn;
    }
    
    
    /**
     * maxDetSerCodigo
     * Retorna o maior cdigo de detalhamento do servio para a solicitao de servio passada como parmetro.
     */
    public java.lang.Integer maxDetSerCodigo(java.lang.Integer solsercodigo) throws SQLException {
         Integer cod = null;
         String sql = "Select max(detser_codigo) as codigo from web.detalheservico where solser_codigo = ? ";
    	 PreparedStatement ps = null;
         try {
            ps = conn.prepareStatement( sql );
            int idx = 0;
            ps.setObject(++idx,solsercodigo);
            ResultSet rs = ps.executeQuery();
            if( rs.next() ) {
                 cod = (java.lang.Integer) rs.getObject("codigo"); 
            }
            } catch( SQLException e ) {
                throw new SQLException(DocumentoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
            } finally {
                if( ps != null ) {
                    ps.close();
                    ps = null;
                }
            }
            if (cod == null) { cod = new Integer("0"); }
    	 return cod;
    }
    
        /**
     * getSomaValoresSolicitacao
     * Retorna a soma dos valores dos servicos realizados para uma determinada solicitacao.
     */
    public java.lang.Double getSomaValoresSolicitacao(java.lang.Integer solsercodigo) throws SQLException {
         java.lang.Double valor = null;
         String sql = "select sum(detser_valor) as detser_valor from web.detalheservico where solser_codigo = ? ";
    	 PreparedStatement ps = null;
         try {
            ps = conn.prepareStatement( sql );
            int idx = 0;
            ps.setObject(++idx,solsercodigo);
            ResultSet rs = ps.executeQuery();
            if( rs.next() ) {
                 valor = (java.lang.Double) rs.getObject("detser_valor"); 
            }
            } catch( SQLException e ) {
                throw new SQLException(DocumentoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
            } finally {
                if( ps != null ) {
                    ps.close();
                    ps = null;
                }
            }
            if (valor == null) { valor = new Double("0"); }
    	 return valor;
    }
    
     /**
     * getSomaValoresPagosSolicitacao
     * Retorna a soma dos valores Pagos dos servicos realizados para uma determinada solicitacao.
     */
    public java.lang.Double getSomaValoresPagosSolicitacao(java.lang.Integer solsercodigo) throws SQLException {
         java.lang.Double valor = null;
         String sql = "select sum(detpag_valpag) as detpag_valpag from web.detalhepagamento where solser_codigo = ? ";
    	 PreparedStatement ps = null;
         try {
            ps = conn.prepareStatement( sql );
            int idx = 0;
            ps.setObject(++idx,solsercodigo);
            ResultSet rs = ps.executeQuery();
            if( rs.next() ) {
                 valor = (java.lang.Double) rs.getObject("detpag_valpag"); 
            }
            } catch( SQLException e ) {
                throw new SQLException(DocumentoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
            } finally {
                if( ps != null ) {
                    ps.close();
                    ps = null;
                }
            }
            if (valor == null) { valor = new Double("0"); }
    	 return valor;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(Detalheservico detalheservico) throws SQLException {
        String sql = "INSERT INTO web.detalheservico " +
                     "(detser_codigo, solser_codigo, status_codigo, detser_descri, detser_datcad, detser_valor, func_codigo) " +
                     "VALUES (?, ?, ?, ?, ?, ?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, detalheservico.getDetserCodigo() );

    	ps.setObject( ++idx, detalheservico.getSolserCodigo() );

    	ps.setObject( ++idx, detalheservico.getStatusCodigo() );

    	ps.setObject( ++idx, detalheservico.getDetserDescri() );

    	ps.setObject( ++idx, new Timestamp(detalheservico.getDetserDatcad().getTime() ));

    	ps.setObject( ++idx, detalheservico.getDetserValor() );

    	ps.setObject( ++idx, detalheservico.getFuncCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(DetalheservicoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(Detalheservico detalheservico) throws SQLException {
        String sql = "UPDATE web.detalheservico SET " +
                     "detser_codigo=?, solser_codigo=?, status_codigo=?, detser_descri=?, detser_datcad=?, detser_valor=?, func_codigo=? " +
                     
                     "WHERE detser_codigo=? AND solser_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, detalheservico.getDetserCodigo() );

    	ps.setObject( ++idx, detalheservico.getSolserCodigo() );

    	ps.setObject( ++idx, detalheservico.getStatusCodigo() );

    	ps.setObject( ++idx, detalheservico.getDetserDescri() );

    	ps.setObject( ++idx, new Timestamp(detalheservico.getDetserDatcad().getTime() ));

    	ps.setObject( ++idx, detalheservico.getDetserValor() );

    	ps.setObject( ++idx, detalheservico.getFuncCodigo() );

    	ps.setObject( ++idx, detalheservico.getDetserCodigo() );

    	ps.setObject( ++idx, detalheservico.getSolserCodigo() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(DetalheservicoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(Detalheservico detalheservico) throws SQLException {
        String sql = "DELETE FROM web.detalheservico " +
                     
                     "WHERE detser_codigo=? AND solser_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, detalheservico.getDetserCodigo() );

    	ps.setObject( ++idx, detalheservico.getSolserCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(DetalheservicoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE detser_codigo=? AND solser_codigo=?";

     */
    public Detalheservico selectPK(java.lang.Integer detserCodigo, java.lang.Integer solserCodigo) throws SQLException {
    	Detalheservico detalheservico = null;
        String sql = "SELECT detser_codigo, solser_codigo, status_codigo, detser_descri, detser_datcad, detser_valor, func_codigo " +
                     "FROM web.detalheservico " +
                     
                     "WHERE detser_codigo=? AND solser_codigo=?";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ps.setObject( ++idx, detserCodigo );
	
    	ps.setObject( ++idx, solserCodigo );
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		detalheservico = new Detalheservico();
    		detalheservico.setDetserCodigo( (java.lang.Integer) rs.getObject("detser_codigo") );
    		detalheservico.setSolserCodigo( (java.lang.Integer) rs.getObject("solser_codigo") );
    		detalheservico.setStatusCodigo( (java.lang.Integer) rs.getObject("status_codigo") );
    		detalheservico.setDetserDescri( (java.lang.String) rs.getObject("detser_descri") );
    		detalheservico.setDetserDatcad( (java.util.Date) rs.getObject("detser_datcad") );
    		detalheservico.setDetserValor( (java.lang.Double) rs.getObject("detser_valor") );
    		detalheservico.setFuncCodigo( (java.lang.Integer) rs.getObject("func_codigo") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(DetalheservicoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return detalheservico;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela detalheservico
     */
    public java.util.List <Detalheservico> getColecao() throws SQLException {
        Detalheservico detalheservico = null;
        String sql = "SELECT detser_codigo, solser_codigo, status_codigo, detser_descri, detser_datcad, detser_valor, func_codigo " +
                     "FROM web.detalheservico ";
        PreparedStatement ps = null;
        java.util.ArrayList <Detalheservico> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		detalheservico = new Detalheservico();
      		detalheservico.setDetserCodigo( (java.lang.Integer) rs.getObject("detser_codigo") );
    		      detalheservico.setSolserCodigo( (java.lang.Integer) rs.getObject("solser_codigo") );
    		      detalheservico.setStatusCodigo( (java.lang.Integer) rs.getObject("status_codigo") );
    		      detalheservico.setDetserDescri( (java.lang.String) rs.getObject("detser_descri") );
    		      detalheservico.setDetserDatcad( (java.util.Date) rs.getObject("detser_datcad") );
    		      detalheservico.setDetserValor( (java.lang.Double) rs.getObject("detser_valor") );
    		      detalheservico.setFuncCodigo( (java.lang.Integer) rs.getObject("func_codigo") );
    		      
                  colec.add( detalheservico );
            }
        } catch( SQLException e ) {
            throw new SQLException(DetalheservicoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
    
    
    /**
     * getColecaoSolicitacao(Integer solser) 
     * retorna todos os registros da tabela detalheservico para a Solicitacao Informada
     */
    public java.util.List <Detalheservico> getColecaoSolicitacao(java.lang.Integer solser) throws SQLException {
        Detalheservico detalheservico = null;
        String sql = "SELECT detser_codigo, solser_codigo, status_codigo, detser_descri, detser_datcad, detser_valor, func_codigo " +
                     "FROM web.detalheservico where solser_codigo = ? ";
        PreparedStatement ps = null;
        java.util.ArrayList <Detalheservico> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            int idx = 0;
            ps.setObject( ++idx, solser );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		detalheservico = new Detalheservico();
      		detalheservico.setDetserCodigo( (java.lang.Integer) rs.getObject("detser_codigo") );
    		      detalheservico.setSolserCodigo( (java.lang.Integer) rs.getObject("solser_codigo") );
    		      detalheservico.setStatusCodigo( (java.lang.Integer) rs.getObject("status_codigo") );
    		      detalheservico.setDetserDescri( (java.lang.String) rs.getObject("detser_descri") );
    		      detalheservico.setDetserDatcad( (java.util.Date) rs.getObject("detser_datcad") );
    		      detalheservico.setDetserValor( (java.lang.Double) rs.getObject("detser_valor") );
    		      detalheservico.setFuncCodigo( (java.lang.Integer) rs.getObject("func_codigo") );
    		      
                  colec.add( detalheservico );
            }
        } catch( SQLException e ) {
            throw new SQLException(DetalheservicoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
    
    
     /**
     * selectUtimoDetalhe
     * retorna o utimo registro de detalhamento de servio cadastrado no banco para uma solicitao de servio
     *    
                     "WHERE solser_codigo=? order by detser_codigo desc limit 1";

     */
    public Detalheservico selectUtimoDetalhe(java.lang.Integer solserCodigo) throws SQLException {
    	Detalheservico detalheservico = null;
        String sql = "SELECT detser_codigo, solser_codigo, status_codigo, detser_descri, detser_datcad, detser_valor, func_codigo " +
                     "FROM web.detalheservico " +
                     
                     "WHERE solser_codigo=? order by detser_codigo desc limit 1";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ps.setObject( ++idx, solserCodigo );
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		detalheservico = new Detalheservico();
    		detalheservico.setDetserCodigo( (java.lang.Integer) rs.getObject("detser_codigo") );
    		detalheservico.setSolserCodigo( (java.lang.Integer) rs.getObject("solser_codigo") );
    		detalheservico.setStatusCodigo( (java.lang.Integer) rs.getObject("status_codigo") );
    		detalheservico.setDetserDescri( (java.lang.String) rs.getObject("detser_descri") );
    		detalheservico.setDetserDatcad( (java.util.Date) rs.getObject("detser_datcad") );
    		detalheservico.setDetserValor( (java.lang.Double) rs.getObject("detser_valor") );
    		detalheservico.setFuncCodigo( (java.lang.Integer) rs.getObject("func_codigo") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(DetalheservicoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return detalheservico;
    }
    
    
}
