
package br.com.tabelionatomessias.dao.web;
/**
 * Sistema: Notarium
 * 
 * Arquivo: DocumentoDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela documento
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class DocumentoDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public DocumentoDAO(Connection conn) {
        this.conn = conn;
    }
    
    /**
     * maxDocCodigo
     * Retorna o maior cdigo de um documento cadastrado no banco.
     */
    public java.lang.Integer maxDocCodigo() throws SQLException {
         Integer cod = null;
         String sql = "Select max(doc_codigo) as codigo from web.documento ";
    	 PreparedStatement ps = null;
         try {
            ps = conn.prepareStatement( sql );
            int idx = 0;
            ps = conn.prepareStatement( sql );
	
            ResultSet rs = ps.executeQuery();
            if( rs.next() ) {
                 cod = (java.lang.Integer) rs.getObject("codigo"); 
            }
            } catch( SQLException e ) {
                throw new SQLException(DocumentoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
            } finally {
                if( ps != null ) {
                    ps.close();
                    ps = null;
                }
            }
            if (cod == null) { cod = new Integer("0"); }
    	 return cod;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(Documento documento) throws SQLException {
        String sql = "INSERT INTO web.documento " +
                     "(doc_codigo, tipato_codigo ,natureza_codigo, doc_objato) " +
                     "VALUES (?, ?, ?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, documento.getDocCodigo() );
        
        ps.setObject( ++idx, documento.getTipatoCodigo() );
        
    	ps.setObject( ++idx, documento.getNaturezaCodigo() );

    	ps.setObject( ++idx, documento.getDocObjato() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(DocumentoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(Documento documento) throws SQLException {
        String sql = "UPDATE web.documento SET " +
                     "doc_codigo=?, natureza_codigo=?, doc_objato=? " +
                     
                     "WHERE doc_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, documento.getDocCodigo() );

    	ps.setObject( ++idx, documento.getNaturezaCodigo() );

    	ps.setObject( ++idx, documento.getDocObjato() );

    	ps.setObject( ++idx, documento.getDocCodigo() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(DocumentoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(Documento documento) throws SQLException {
        String sql = "DELETE FROM web.documento " +
                     
                     "WHERE doc_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, documento.getDocCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(DocumentoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE doc_codigo=?";
     */
    public Documento selectPK(java.lang.Integer docCodigo) throws SQLException {
    	Documento documento = null;
        String sql = "SELECT doc_codigo, tipato_codigo ,natureza_codigo, doc_objato " +
                     "FROM web.documento " +
                     
                     "WHERE doc_codigo=?";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ps.setObject( ++idx, docCodigo );
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		documento = new Documento();
    		documento.setDocCodigo( (java.lang.Integer) rs.getObject("doc_codigo") );
                documento.setTipatoCodigo( (java.lang.Integer) rs.getObject("tipato_codigo"));
    		documento.setNaturezaCodigo( (java.lang.Integer) rs.getObject("natureza_codigo") );
    		documento.setDocObjato( (java.lang.String) rs.getObject("doc_objato") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(DocumentoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return documento;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela documento
     */
    public java.util.List <Documento> getColecao() throws SQLException {
        Documento documento = null;
        String sql = "SELECT doc_codigo, natureza_codigo, doc_objato " +
                     "FROM web.documento ";
        PreparedStatement ps = null;
        java.util.ArrayList <Documento> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		documento = new Documento();
      		documento.setDocCodigo( (java.lang.Integer) rs.getObject("doc_codigo") );
    		      documento.setNaturezaCodigo( (java.lang.Integer) rs.getObject("natureza_codigo") );
    		      documento.setDocObjato( (java.lang.String) rs.getObject("doc_objato") );
    		      
                  colec.add( documento );
            }
        } catch( SQLException e ) {
            throw new SQLException(DocumentoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
}
