
package br.com.tabelionatomessias.dao.web;
/**
 * Sistema: Notarium
 * 
 * Arquivo: DocumentoParticipantesDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import br.com.tabelionatomessias.dao.cart.PessoaDAO;
import br.com.tabelionatomessias.dao.cart.Pessoa;
import br.com.tabelionatomessias.dao.web.PessoaTempDAO;
import br.com.tabelionatomessias.dao.web.PessoaTemp;
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela documento_participantes
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class DocumentoParticipantesDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public DocumentoParticipantesDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(DocumentoParticipantes documentoParticipantes) throws SQLException {
        String sql = "INSERT INTO web.documento_participantes " +
                     "(doc_codigo, pes_codigo, pap_codigo) " +
                     "VALUES (?, ?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, documentoParticipantes.getDocCodigo() );

    	ps.setObject( ++idx, documentoParticipantes.getPesCodigo() );

    	ps.setObject( ++idx, documentoParticipantes.getPapCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(DocumentoParticipantesDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(DocumentoParticipantes documentoParticipantes) throws SQLException {
        String sql = "UPDATE web.documento_participantes SET " +
                     "doc_codigo=?, pes_codigo=?, pap_codigo=? " +
                     
                     "WHERE doc_codigo=? AND pes_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, documentoParticipantes.getDocCodigo() );

    	ps.setObject( ++idx, documentoParticipantes.getPesCodigo() );

    	ps.setObject( ++idx, documentoParticipantes.getPapCodigo() );

    	ps.setObject( ++idx, documentoParticipantes.getDocCodigo() );

    	ps.setObject( ++idx, documentoParticipantes.getPesCodigo() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(DocumentoParticipantesDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(DocumentoParticipantes documentoParticipantes) throws SQLException {
        String sql = "DELETE FROM web.documento_participantes " +
                     
                     "WHERE doc_codigo=? AND pes_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, documentoParticipantes.getDocCodigo() );

    	ps.setObject( ++idx, documentoParticipantes.getPesCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(DocumentoParticipantesDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }
    
    
        /**
     * deleteParticipantesDocumento
     * excluir um registro no banco de dados.
     */
    public void deleteParticipantesDocumento(Integer doccodigo) throws SQLException {
        String sql = "DELETE FROM web.documento_participantes " +
                     
                     "WHERE doc_codigo=? ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;    	   
      	   ps.setObject( ++idx, doccodigo );
    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(DocumentoParticipantesDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }
    

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE doc_codigo=? AND pes_codigo=?";

     */
    public DocumentoParticipantes selectPK(java.lang.Integer docCodigo, java.lang.Integer pesCodigo) throws SQLException {
    	DocumentoParticipantes documentoParticipantes = null;
        String sql = "SELECT doc_codigo, pes_codigo, pap_codigo " +
                     "FROM documento_participantes " +
                     
                     "WHERE doc_codigo=? AND pes_codigo=?";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ps.setObject( ++idx, docCodigo );
	
    	ps.setObject( ++idx, pesCodigo );
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		documentoParticipantes = new DocumentoParticipantes();
    		documentoParticipantes.setDocCodigo( (java.lang.Integer) rs.getObject("doc_codigo") );
    		documentoParticipantes.setPesCodigo( (java.lang.Integer) rs.getObject("pes_codigo") );
    		documentoParticipantes.setPapCodigo( (java.lang.Integer) rs.getObject("pap_codigo") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(DocumentoParticipantesDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return documentoParticipantes;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela documento_participantes
     */
    public java.util.List <DocumentoParticipantes> getColecao() throws SQLException {
        DocumentoParticipantes documentoParticipantes = null;
        String sql = "SELECT doc_codigo, pes_codigo, pap_codigo " +
                     "FROM documento_participantes ";
        PreparedStatement ps = null;
        java.util.ArrayList <DocumentoParticipantes> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		documentoParticipantes = new DocumentoParticipantes();
      		documentoParticipantes.setDocCodigo( (java.lang.Integer) rs.getObject("doc_codigo") );
    		      documentoParticipantes.setPesCodigo( (java.lang.Integer) rs.getObject("pes_codigo") );
    		      documentoParticipantes.setPapCodigo( (java.lang.Integer) rs.getObject("pap_codigo") );
    		      
                  colec.add( documentoParticipantes );
            }
        } catch( SQLException e ) {
            throw new SQLException(DocumentoParticipantesDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
    
     /**
     * getParticipantesDocumento
     * retorna todos os registros da tabela documento_participantes que estejam relacionados com um documento especifico.
     */
    public java.util.List <DocumentoParticipantes> getParticipantesDocumento(java.lang.Integer doccodigo) throws SQLException {
        DocumentoParticipantes documentoParticipantes = null;
        String sql = "SELECT doc_codigo, pes_codigo, pap_codigo " +
                     "FROM web.documento_participantes " +
                     "WHERE doc_codigo=? ";
        PreparedStatement ps = null;
        java.util.ArrayList <DocumentoParticipantes> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            int idx = 0;
            ps.setObject(++idx,doccodigo);
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		documentoParticipantes = new DocumentoParticipantes();
      		documentoParticipantes.setDocCodigo( (java.lang.Integer) rs.getObject("doc_codigo") );
    		      documentoParticipantes.setPesCodigo( (java.lang.Integer) rs.getObject("pes_codigo") );
    		      documentoParticipantes.setPapCodigo( (java.lang.Integer) rs.getObject("pap_codigo") );
                      if (documentoParticipantes.getPesCodigo() > new Integer(900000)) {
    		        documentoParticipantes.setTipoPessoa(new Integer(2));
                        PessoaTempDAO daopessoatemp = new PessoaTempDAO(this.conn);
                        PessoaTemp pessoatemp = daopessoatemp.selectPK(documentoParticipantes.getPesCodigo());
                        documentoParticipantes.setPessoaTemp(pessoatemp);
                      } else {
                        documentoParticipantes.setTipoPessoa(new Integer(1));
                        PessoaDAO daopessoa = new PessoaDAO(this.conn);
                        Pessoa pessoa = daopessoa.selectPK(documentoParticipantes.getPesCodigo());
                        documentoParticipantes.setPessoa(pessoa);
                      }
                  colec.add( documentoParticipantes );
            }
        } catch( SQLException e ) {
            throw new SQLException(DocumentoParticipantesDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
}
