
package br.com.tabelionatomessias.dao.web;
/**
 * Sistema: Notarium
 * 
 * Arquivo: DocumentoarquivoDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;
import java.sql.Timestamp;
import java.util.Date;

/**
 * Classe que implementa o padro DAO da tabela documentoarquivo
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class DocumentoarquivoDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public DocumentoarquivoDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(Documentoarquivo documentoarquivo) throws SQLException {
        String sql = " INSERT INTO web.documentoarquivo " +
                     " (doc_codigo, doc_arquivo, doc_assinado, doc_md5, doc_sha, doc_nome_arquivo, doc_data_envio, doc_verificador) " +
                     " VALUES (?, ?, ?, ?, ?, ?, now(), ?) ";
    	PreparedStatement ps = null;
      try {
            ps = conn.prepareStatement( sql );
            int idx = 0;
    	    
            ps.setObject( ++idx, documentoarquivo.getDocCodigo() );
            ps.setObject( ++idx, documentoarquivo.getDocArquivo() );
            ps.setObject( ++idx, documentoarquivo.getAssinatura() );
            ps.setObject( ++idx, documentoarquivo.getMD5() );
            ps.setObject( ++idx, documentoarquivo.getSHA() );
            ps.setObject( ++idx, documentoarquivo.getNomeArquivo());
            ps.setObject( ++idx, documentoarquivo.getDocverificador());

            ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(DocumentoarquivoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(Documentoarquivo documentoarquivo) throws SQLException {
        String sql = "UPDATE web.documentoarquivo SET " +
                     "doc_codigo=?, doc_arquivo=?, doc_assinado=? " +
                     "WHERE doc_codigo=?";

    	PreparedStatement ps = null;
      try {
            ps = conn.prepareStatement( sql );
             int idx = 0;
    	   
            ps.setObject( ++idx, documentoarquivo.getDocCodigo() );
            ps.setObject( ++idx, documentoarquivo.getDocArquivo() );
            ps.setObject( ++idx, documentoarquivo.getAssinatura() );
            ps.setObject( ++idx, documentoarquivo.getDocCodigo() );

            ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(DocumentoarquivoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(Documentoarquivo documentoarquivo) throws SQLException {
        String sql = "DELETE FROM web.documentoarquivo WHERE doc_codigo=?";

        PreparedStatement ps = null;
        try {
            ps = conn.prepareStatement( sql );
            int idx = 0;
            ps.setObject( ++idx, documentoarquivo.getDocCodigo() );
            ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(DocumentoarquivoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     */
    public Documentoarquivo selectPK(java.lang.Integer docCodigo) throws SQLException {
    	Documentoarquivo documentoarquivo = null;
        String sql = "SELECT doc_codigo, doc_arquivo, doc_assinado " +
                     "FROM web.documentoarquivo WHERE doc_codigo=?";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
    	ps.setObject( ++idx, docCodigo );
    	ResultSet rs = ps.executeQuery();

        if( rs.next() ) {
    		documentoarquivo = new Documentoarquivo();
    		documentoarquivo.setDocCodigo( (Integer) rs.getObject("doc_codigo") );
    		documentoarquivo.setDocArquivo( (byte[]) rs.getObject("doc_arquivo") );
    		documentoarquivo.setAssinatura( (byte[]) rs.getObject("doc_assinado") );
        }
        
        } catch( SQLException e ) {
            throw new SQLException(DocumentoarquivoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return documentoarquivo;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela documentoarquivo
     */
    public java.util.List <Documentoarquivo> getColecao(String restricao) throws SQLException {
        Documentoarquivo documentoarquivo = null;
        String sql = " SELECT doc_codigo, doc_arquivo, doc_assinado, doc_md5, doc_sha, " +
                     " doc_nome_arquivo, doc_data_envio, doc_verificador FROM web.documentoarquivo ";
        if (!restricao.equals(null)) {
            sql = sql + restricao;
        }
        PreparedStatement ps = null;
        java.util.ArrayList <Documentoarquivo> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            
            while( rs.next() ) {
       		documentoarquivo = new Documentoarquivo();
      		documentoarquivo.setDocCodigo( (Integer) rs.getObject("doc_codigo") );
    		documentoarquivo.setDocArquivo( (byte[]) rs.getObject("doc_arquivo") );
    		documentoarquivo.setAssinatura( (byte[]) rs.getObject("doc_assinado") );
      		documentoarquivo.setMD5( (String) rs.getObject("doc_md5") );
    		documentoarquivo.setSHA( (String) rs.getObject("doc_sha") );
                documentoarquivo.setNomeArquivo( (String) rs.getObject("doc_nome_arquivo") );
    		documentoarquivo.setDataEnvio( (Date) rs.getObject("doc_data_envio") );
                documentoarquivo.setDocverificador((String) rs.getObject("doc_verificador") );
                colec.add( documentoarquivo );
            }
            
        } catch( SQLException e ) {
            throw new SQLException(DocumentoarquivoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
    
    
    /**
     * selectCript
     * busca um registro pela criptografia. 
     */
    public Documentoarquivo selectCripto(String md5, String sha1) throws SQLException {
    	Documentoarquivo documentoarquivo = null;
        String sql = "SELECT doc_codigo, doc_arquivo, doc_assinado, doc_md5, doc_sha, doc_nome_arquivo, doc_data_envio, doc_verificador " +
                     "FROM web.documentoarquivo WHERE doc_md5 = ? AND doc_sha = ?" ;
        PreparedStatement ps = null;
        try {
            ps = conn.prepareStatement( sql );
            int idx = 0;
            ps.setObject( ++idx, md5 );
            ps.setObject( ++idx, sha1 );
            ResultSet rs = ps.executeQuery();

        if( rs.next() ) {
    		documentoarquivo = new Documentoarquivo();
    		documentoarquivo.setDocCodigo( (Integer) rs.getObject("doc_codigo") );
    		documentoarquivo.setDocArquivo( (byte[]) rs.getObject("doc_arquivo") );
    		documentoarquivo.setAssinatura( (byte[]) rs.getObject("doc_assinado") );
                documentoarquivo.setMD5( (String) rs.getObject("doc_md5") );
                documentoarquivo.setSHA( (String) rs.getObject("doc_sha") );
                documentoarquivo.setNomeArquivo( (String) rs.getObject("doc_nome_arquivo") );
                documentoarquivo.setDataEnvio( (Date) rs.getObject("doc_data_envio") );
                documentoarquivo.setDocverificador( (String) rs.getObject("doc_verificador") );
                
        }
        
        } catch( SQLException e ) {
            throw new SQLException(DocumentoarquivoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return documentoarquivo;
    }
    
        
    
    /**
     * selectVerificador
     * busca um registro pelo cdigo de Verificao. 
     */
    public Documentoarquivo selectVerificador(String val) throws SQLException {
    	Documentoarquivo documentoarquivo = null;
        String sql = "SELECT doc_codigo, doc_arquivo, doc_assinado, doc_md5, doc_sha, doc_verificador " +
                     "FROM web.documentoarquivo WHERE doc_verificador LIKE ? " ;
        PreparedStatement ps = null;
        try {
            ps = conn.prepareStatement( sql );
            int idx = 0;
            ps.setObject( ++idx, val );
         //   ps.setObject( ++idx, sha1 );
            ResultSet rs = ps.executeQuery();

        if( rs.next() ) {
    		documentoarquivo = new Documentoarquivo();
    		documentoarquivo.setDocCodigo( (Integer) rs.getObject("doc_codigo") );
    		documentoarquivo.setDocArquivo( (byte[]) rs.getObject("doc_arquivo") );
    		documentoarquivo.setAssinatura( (byte[]) rs.getObject("doc_assinado") );
                documentoarquivo.setMD5( (String) rs.getObject("doc_md5") );
                documentoarquivo.setSHA( (String) rs.getObject("doc_sha") );
                documentoarquivo.setDocverificador( (String) rs.getObject("doc_verificador"));
        }
        
        } catch( SQLException e ) {
            throw new SQLException(DocumentoarquivoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return documentoarquivo;
    }
    
    
}
