
package br.com.tabelionatomessias.dao.web;
/**
 * Sistema: Notarium
 * 
 * Arquivo: EntregasolicitacaoDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela entregasolicitacao
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class EntregasolicitacaoDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public EntregasolicitacaoDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(Entregasolicitacao entregasolicitacao) throws SQLException {
        String sql = "INSERT INTO web.entregasolicitacao " +
                     "(solser_codigo, forent_codigo, entsol_uf, entsol_loccodigo, entsol_cep, entsol_logcodigo, entsol_comple, entsol_email) " +
                     "VALUES (?, ?, ?, ?, ?, ?, ?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, entregasolicitacao.getSolserCodigo() );

    	ps.setObject( ++idx, entregasolicitacao.getForentCodigo() );

    	ps.setObject( ++idx, entregasolicitacao.getEntsolUf() );

    	ps.setObject( ++idx, entregasolicitacao.getEntsolLoccodigo() );

    	ps.setObject( ++idx, entregasolicitacao.getEntsolCep() );

    	ps.setObject( ++idx, entregasolicitacao.getEntsolLogcodigo() );

    	ps.setObject( ++idx, entregasolicitacao.getEntsolComple() );

    	ps.setObject( ++idx, entregasolicitacao.getEntsolEmail() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(EntregasolicitacaoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(Entregasolicitacao entregasolicitacao) throws SQLException {
        String sql = "UPDATE web.entregasolicitacao SET " +
                     "solser_codigo=?, forent_codigo=?, entsol_uf=?, entsol_loccodigo=?, entsol_cep=?, entsol_logcodigo=?, entsol_comple=?, entsol_email=? " +
                     
                     "WHERE solser_codigo=? ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, entregasolicitacao.getSolserCodigo() );

    	ps.setObject( ++idx, entregasolicitacao.getForentCodigo() );

    	ps.setObject( ++idx, entregasolicitacao.getEntsolUf() );

    	ps.setObject( ++idx, entregasolicitacao.getEntsolLoccodigo() );

    	ps.setObject( ++idx, entregasolicitacao.getEntsolCep() );

    	ps.setObject( ++idx, entregasolicitacao.getEntsolLogcodigo() );

    	ps.setObject( ++idx, entregasolicitacao.getEntsolComple() );

    	ps.setObject( ++idx, entregasolicitacao.getEntsolEmail() );

    	ps.setObject( ++idx, entregasolicitacao.getSolserCodigo() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(EntregasolicitacaoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(Entregasolicitacao entregasolicitacao) throws SQLException {
        String sql = "DELETE FROM web.entregasolicitacao " +
                     
                     "WHERE solser_codigo=? AND forent_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, entregasolicitacao.getSolserCodigo() );

    	ps.setObject( ++idx, entregasolicitacao.getForentCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(EntregasolicitacaoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE solser_codigo=? AND forent_codigo=?";

     */
    public Entregasolicitacao selectPK(java.lang.Integer solserCodigo) throws SQLException {
    	Entregasolicitacao entregasolicitacao = null;
        String sql = "SELECT solser_codigo, forent_codigo, entsol_uf, entsol_loccodigo, entsol_cep, entsol_logcodigo, entsol_comple, entsol_email " +
                     "FROM web.entregasolicitacao " +
                     
                     "WHERE solser_codigo=? ";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ps.setObject( ++idx, solserCodigo );
	
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		entregasolicitacao = new Entregasolicitacao();
    		entregasolicitacao.setSolserCodigo( (java.lang.Integer) rs.getObject("solser_codigo") );
    		entregasolicitacao.setForentCodigo( (java.lang.Integer) rs.getObject("forent_codigo") );
    		entregasolicitacao.setEntsolUf( (java.lang.Integer) rs.getObject("entsol_uf") );
    		entregasolicitacao.setEntsolLoccodigo( (java.lang.Integer) rs.getObject("entsol_loccodigo") );
    		entregasolicitacao.setEntsolCep( (java.lang.Integer) rs.getObject("entsol_cep") );
    		entregasolicitacao.setEntsolLogcodigo( (java.lang.Integer) rs.getObject("entsol_logcodigo") );
    		entregasolicitacao.setEntsolComple( (java.lang.String) rs.getObject("entsol_comple") );
    		entregasolicitacao.setEntsolEmail( (java.lang.String) rs.getObject("entsol_email") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(EntregasolicitacaoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return entregasolicitacao;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela entregasolicitacao
     */
    public java.util.List <Entregasolicitacao> getColecao() throws SQLException {
        Entregasolicitacao entregasolicitacao = null;
        String sql = "SELECT solser_codigo, forent_codigo, entsol_uf, entsol_loccodigo, entsol_cep, entsol_logcodigo, entsol_comple, entsol_email " +
                     "FROM web.entregasolicitacao ";
        PreparedStatement ps = null;
        java.util.ArrayList <Entregasolicitacao> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		entregasolicitacao = new Entregasolicitacao();
      		entregasolicitacao.setSolserCodigo( (java.lang.Integer) rs.getObject("solser_codigo") );
    		      entregasolicitacao.setForentCodigo( (java.lang.Integer) rs.getObject("forent_codigo") );
    		      entregasolicitacao.setEntsolUf( (java.lang.Integer) rs.getObject("entsol_uf") );
    		      entregasolicitacao.setEntsolLoccodigo( (java.lang.Integer) rs.getObject("entsol_loccodigo") );
    		      entregasolicitacao.setEntsolCep( (java.lang.Integer) rs.getObject("entsol_cep") );
    		      entregasolicitacao.setEntsolLogcodigo( (java.lang.Integer) rs.getObject("entsol_logcodigo") );
    		      entregasolicitacao.setEntsolComple( (java.lang.String) rs.getObject("entsol_comple") );
    		      entregasolicitacao.setEntsolEmail( (java.lang.String) rs.getObject("entsol_email") );
    		      
                  colec.add( entregasolicitacao );
            }
        } catch( SQLException e ) {
            throw new SQLException(EntregasolicitacaoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
    
}
