package br.com.tabelionatomessias.dao.web;
/**
 * Sistema: Notarium
 * 
 * Arquivo: FormaentregaDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela formaentrega
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class FormaentregaDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public FormaentregaDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(Formaentrega formaentrega) throws SQLException {
        String sql = "INSERT INTO formaentrega " +
                     "(forent_codigo, forent_descri) " +
                     "VALUES (?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, formaentrega.getForentCodigo() );

    	ps.setObject( ++idx, formaentrega.getForentDescri() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(FormaentregaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(Formaentrega formaentrega) throws SQLException {
        String sql = "UPDATE formaentrega SET " +
                     "forent_codigo=?, forent_descri=? " +
                     
                     "WHERE forent_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, formaentrega.getForentCodigo() );

    	ps.setObject( ++idx, formaentrega.getForentDescri() );

    	ps.setObject( ++idx, formaentrega.getForentCodigo() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(FormaentregaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(Formaentrega formaentrega) throws SQLException {
        String sql = "DELETE FROM formaentrega " +
                     
                     "WHERE forent_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, formaentrega.getForentCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(FormaentregaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE forent_codigo=?";

     */
    public Formaentrega selectPK(java.lang.Integer forentCodigo) throws SQLException {
    	Formaentrega formaentrega = null;
        String sql = "SELECT forent_codigo, forent_descri " +
                     "FROM web.formaentrega " +
                     
                     "WHERE forent_codigo=?";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ps.setObject( ++idx, forentCodigo );
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		formaentrega = new Formaentrega();
    		formaentrega.setForentCodigo( (java.lang.Integer) rs.getObject("forent_codigo") );
    		formaentrega.setForentDescri( (java.lang.String) rs.getObject("forent_descri") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(FormaentregaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return formaentrega;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela formaentrega
     */
    public java.util.List <Formaentrega> getColecao() throws SQLException {
        Formaentrega formaentrega = null;
        String sql = "SELECT forent_codigo, forent_descri " +
                     "FROM web.formaentrega ";
        PreparedStatement ps = null;
        java.util.ArrayList <Formaentrega> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		formaentrega = new Formaentrega();
      		formaentrega.setForentCodigo( (java.lang.Integer) rs.getObject("forent_codigo") );
    		      formaentrega.setForentDescri( (java.lang.String) rs.getObject("forent_descri") );
    		      
                  colec.add( formaentrega );
            }
        } catch( SQLException e ) {
            throw new SQLException(FormaentregaDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
}
