
package br.com.tabelionatomessias.dao.web;
/**
 * Sistema: Notarium
 * 
 * Arquivo: PapelDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela papel
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class PapelDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public PapelDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(Papel papel) throws SQLException {
        String sql = "INSERT INTO papel " +
                     "(pap_codigo, pap_descri) " +
                     "VALUES (?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, papel.getPapCodigo() );

    	ps.setObject( ++idx, papel.getPapDescri() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(PapelDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(Papel papel) throws SQLException {
        String sql = "UPDATE papel SET " +
                     "pap_codigo=?, pap_descri=? " +
                     
                     "WHERE pap_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, papel.getPapCodigo() );

    	ps.setObject( ++idx, papel.getPapDescri() );

    	ps.setObject( ++idx, papel.getPapCodigo() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(PapelDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(Papel papel) throws SQLException {
        String sql = "DELETE FROM web.papel " +
                     
                     "WHERE pap_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, papel.getPapCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(PapelDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE pap_codigo=?";

     */
    public Papel selectPK(java.lang.Integer papCodigo) throws SQLException {
    	Papel papel = null;
        String sql = "SELECT pap_codigo, pap_descri " +
                     "FROM web.papel " +
                     
                     "WHERE pap_codigo=?";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ps.setObject( ++idx, papCodigo );
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		papel = new Papel();
    		papel.setPapCodigo( (java.lang.Integer) rs.getObject("pap_codigo") );
    		papel.setPapDescri( (java.lang.String) rs.getObject("pap_descri") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(PapelDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return papel;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela papel
     */
    public java.util.List <Papel> getColecao() throws SQLException {
        Papel papel = null;
        String sql = "SELECT pap_codigo, pap_descri " +
                     "FROM web.papel ";
        PreparedStatement ps = null;
        java.util.ArrayList <Papel> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		papel = new Papel();
      		papel.setPapCodigo( (java.lang.Integer) rs.getObject("pap_codigo") );
    		      papel.setPapDescri( (java.lang.String) rs.getObject("pap_descri") );
    		      
                  colec.add( papel );
            }
        } catch( SQLException e ) {
            throw new SQLException(PapelDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
    
    /**
     * getPapeisNatureza
     * retorna todos os registros da tabela papel de acordo com a Natureza e o Tipo do Documento
     */
    public java.util.List <Papel> getPapeisNatureza(java.lang.Integer natcodigo, java.lang.Integer tipatocodigo) throws SQLException {
        Papel papel = null;
        String sql = "SELECT pap.pap_codigo, pap.pap_descri " +
                     "FROM web.papel pap, web.papel_natureza papnat " +
                     "WHERE pap.pap_codigo = papnat.pap_codigo and papnat.natureza_codigo = ? and papnat.natureza_tipo = ? ";
        PreparedStatement ps = null;
        java.util.ArrayList <Papel> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            int idx = 0;
    	    ps.setObject( ++idx, natcodigo );
            ps.setObject( ++idx, tipatocodigo );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		papel = new Papel();
      		papel.setPapCodigo( (java.lang.Integer) rs.getObject("pap_codigo") );
    	papel.setPapDescri( (java.lang.String) rs.getObject("pap_descri") );
    		      
                  colec.add( papel );
            }
        } catch( SQLException e ) {
            throw new SQLException(PapelDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
}
