
package br.com.tabelionatomessias.dao.web;
/**
 * Sistema: Notarium
 * 
 * Arquivo: PapelNaturezadocumentoDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela papel_naturezadocumento
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class PapelNaturezadocumentoDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public PapelNaturezadocumentoDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(PapelNaturezadocumento papelNaturezadocumento) throws SQLException {
        String sql = "INSERT INTO papel_naturezadocumento " +
                     "(natureza_codigo, pap_codigo) " +
                     "VALUES (?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, papelNaturezadocumento.getNaturezaCodigo() );

    	ps.setObject( ++idx, papelNaturezadocumento.getPapCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(PapelNaturezadocumentoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(PapelNaturezadocumento papelNaturezadocumento) throws SQLException {
        String sql = "UPDATE papel_naturezadocumento SET " +
                     "natureza_codigo=?, pap_codigo=? " +
                     
                     "WHERE natureza_codigo=? AND pap_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, papelNaturezadocumento.getNaturezaCodigo() );

    	ps.setObject( ++idx, papelNaturezadocumento.getPapCodigo() );

    	ps.setObject( ++idx, papelNaturezadocumento.getNaturezaCodigo() );

    	ps.setObject( ++idx, papelNaturezadocumento.getPapCodigo() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(PapelNaturezadocumentoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(PapelNaturezadocumento papelNaturezadocumento) throws SQLException {
        String sql = "DELETE FROM papel_naturezadocumento " +
                     
                     "WHERE natureza_codigo=? AND pap_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, papelNaturezadocumento.getNaturezaCodigo() );

    	ps.setObject( ++idx, papelNaturezadocumento.getPapCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(PapelNaturezadocumentoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE natureza_codigo=? AND pap_codigo=?";

     */
    public PapelNaturezadocumento selectPK(java.lang.Integer naturezaCodigo, java.lang.Integer papCodigo) throws SQLException {
    	PapelNaturezadocumento papelNaturezadocumento = null;
        String sql = "SELECT natureza_codigo, pap_codigo " +
                     "FROM papel_naturezadocumento " +
                     
                     "WHERE natureza_codigo=? AND pap_codigo=?";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ps.setObject( ++idx, naturezaCodigo );
	
    	ps.setObject( ++idx, papCodigo );
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		papelNaturezadocumento = new PapelNaturezadocumento();
    		papelNaturezadocumento.setNaturezaCodigo( (java.lang.Integer) rs.getObject("natureza_codigo") );
    		papelNaturezadocumento.setPapCodigo( (java.lang.Integer) rs.getObject("pap_codigo") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(PapelNaturezadocumentoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return papelNaturezadocumento;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela papel_naturezadocumento
     */
    public java.util.List <PapelNaturezadocumento> getColecao() throws SQLException {
        PapelNaturezadocumento papelNaturezadocumento = null;
        String sql = "SELECT natureza_codigo, pap_codigo " +
                     "FROM papel_naturezadocumento ";
        PreparedStatement ps = null;
        java.util.ArrayList <PapelNaturezadocumento> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		papelNaturezadocumento = new PapelNaturezadocumento();
      		papelNaturezadocumento.setNaturezaCodigo( (java.lang.Integer) rs.getObject("natureza_codigo") );
    		      papelNaturezadocumento.setPapCodigo( (java.lang.Integer) rs.getObject("pap_codigo") );
    		      
                  colec.add( papelNaturezadocumento );
            }
        } catch( SQLException e ) {
            throw new SQLException(PapelNaturezadocumentoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
}
