
package br.com.tabelionatomessias.dao.web;
/**
 * Sistema: Notarium
 * 
 * Arquivo: PapelPkeyDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela papel_pkey
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class PapelPkeyDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public PapelPkeyDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(PapelPkey papelPkey) throws SQLException {
        String sql = "INSERT INTO papel_pkey " +
                     "(pap_codigo) " +
                     "VALUES (?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, papelPkey.getPapCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(PapelPkeyDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(PapelPkey papelPkey) throws SQLException {
        String sql = "UPDATE papel_pkey SET " +
                     "pap_codigo=? " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, papelPkey.getPapCodigo() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(PapelPkeyDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(PapelPkey papelPkey) throws SQLException {
        String sql = "DELETE FROM papel_pkey " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(PapelPkeyDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE ";

     */
    public PapelPkey selectPK() throws SQLException {
    	PapelPkey papelPkey = null;
        String sql = "SELECT pap_codigo " +
                     "FROM papel_pkey " +
                     
                     "WHERE ";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		papelPkey = new PapelPkey();
    		papelPkey.setPapCodigo( (java.lang.Integer) rs.getObject("pap_codigo") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(PapelPkeyDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return papelPkey;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela papel_pkey
     */
    public java.util.List <PapelPkey> getColecao() throws SQLException {
        PapelPkey papelPkey = null;
        String sql = "SELECT pap_codigo " +
                     "FROM papel_pkey ";
        PreparedStatement ps = null;
        java.util.ArrayList <PapelPkey> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		papelPkey = new PapelPkey();
      		papelPkey.setPapCodigo( (java.lang.Integer) rs.getObject("pap_codigo") );
    		      
                  colec.add( papelPkey );
            }
        } catch( SQLException e ) {
            throw new SQLException(PapelPkeyDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
}
