
package br.com.tabelionatomessias.dao.web;
/**
 * Sistema: Notarium
 * 
 * Arquivo: StatusDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela status
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 */
public class StatusDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public StatusDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(Status status) throws SQLException {
        String sql = "INSERT INTO status " +
                     "(status_codigo, status_descri) " +
                     "VALUES (?, ?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, status.getStatusCodigo() );

    	ps.setObject( ++idx, status.getStatusDescri() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(StatusDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(Status status) throws SQLException {
        String sql = "UPDATE status SET " +
                     "status_codigo=?, status_descri=? " +
                     
                     "WHERE status_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, status.getStatusCodigo() );

    	ps.setObject( ++idx, status.getStatusDescri() );

    	ps.setObject( ++idx, status.getStatusCodigo() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(StatusDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(Status status) throws SQLException {
        String sql = "DELETE FROM status " +
                     
                     "WHERE status_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, status.getStatusCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(StatusDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     *    
                     "WHERE status_codigo=?";

     */
    public Status selectPK(java.lang.Integer statusCodigo) throws SQLException {
    	Status status = null;
        String sql = "SELECT status_codigo, status_descri " +
                     "FROM web.status " +
                     
                     "WHERE status_codigo=? ";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ps.setObject( ++idx, statusCodigo );
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		status = new Status();
    		status.setStatusCodigo( (java.lang.Integer) rs.getObject("status_codigo") );
    		status.setStatusDescri( (java.lang.String) rs.getObject("status_descri") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(StatusDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return status;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela status
     */
    public java.util.List <Status> getColecao() throws SQLException {
        Status status = null;
        String sql = "SELECT status_codigo, status_descri " +
                     "FROM status ";
        PreparedStatement ps = null;
        java.util.ArrayList <Status> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		status = new Status();
      		status.setStatusCodigo( (java.lang.Integer) rs.getObject("status_codigo") );
    		status.setStatusDescri( (java.lang.String) rs.getObject("status_descri") );      
                colec.add( status );
            }
        } catch( SQLException e ) {
            throw new SQLException(StatusDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
}
