
package br.com.tabelionatomessias.dao.web;
/**
 * Sistema: Notarium
 * 
 * Arquivo: TiposolicitacaoDAO.java
 *
 * Autor: JLMM
 * Data de criao: 05/09/2006
 *
 * ltimas alteraes (mantenha o formato abaixo)
 *   Data,      Autor,   Finalidade
 *
 */
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.PreparedStatement;

/**
 * Classe que implementa o padro DAO da tabela tiposolicitacao
 * recebe como parmetro basico um objeto de conexo com o banco de dados. 
 *
 * @author JLMM
 */
public class TiposolicitacaoDAO {
    private Connection conn = null;

    /**
     * Construtor
     * @param conn - um objeto java.sql.Connection de conexo com o banco de dados
     */
    public TiposolicitacaoDAO(Connection conn) {
        this.conn = conn;
    }

    /**
     * insert
     * salvar um novo registro no banco de dados.
     */
    public void insert(Tiposolicitacao tiposolicitacao) throws SQLException {
        String sql = "INSERT INTO web.tiposolicitacao " +
                     "(tipsol_codigo, tipsol_descri, tipsol_valor) " +
                     "VALUES (?, ?, ?)";
    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, tiposolicitacao.getTipsolCodigo() );
    	ps.setObject( ++idx, tiposolicitacao.getTipsolDescri() );
        ps.setObject( ++idx, tiposolicitacao.getTipsolValor() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(TiposolicitacaoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * update
     * salvar as alteraes de um registro no banco de dados.
     */
    public void update(Tiposolicitacao tiposolicitacao) throws SQLException {
        String sql = "UPDATE web.tiposolicitacao SET " +
                     "tipsol_codigo=?, tipsol_descri=? , tipsol_valor=?" +                     
                     "WHERE tipsol_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, tiposolicitacao.getTipsolCodigo() );
    	ps.setObject( ++idx, tiposolicitacao.getTipsolDescri() );
    	ps.setObject( ++idx, tiposolicitacao.getTipsolValor() );

	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(TiposolicitacaoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * delete
     * excluir um registro no banco de dados.
     */
    public void delete(Tiposolicitacao tiposolicitacao) throws SQLException {
        String sql = "DELETE FROM web.tiposolicitacao " +                     
                     "WHERE tipsol_codigo=?";

    	PreparedStatement ps = null;
      try {
    	   ps = conn.prepareStatement( sql );
	   int idx = 0;
    	   
    	ps.setObject( ++idx, tiposolicitacao.getTipsolCodigo() );

    	   ps.executeUpdate();
        } catch( SQLException e ) {
            throw new SQLException(TiposolicitacaoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    }

    /**
     * selectPk
     * busca um registro pela chave primria do banco. 
     */
    public Tiposolicitacao selectPK(java.lang.Integer tipsolCodigo) throws SQLException {
    	Tiposolicitacao tiposolicitacao = null;
        String sql = "SELECT tipsol_codigo, tipsol_descri, tipsol_valor " +
                     "FROM web.tiposolicitacao WHERE tipsol_codigo=?";

    	PreparedStatement ps = null;
      try {
    	ps = conn.prepareStatement( sql );
	int idx = 0;
	
    	ps.setObject( ++idx, tipsolCodigo );
	
    	ResultSet rs = ps.executeQuery();
    	if( rs.next() ) {
    		tiposolicitacao = new Tiposolicitacao();
    		tiposolicitacao.setTipsolCodigo( (Integer) rs.getObject("tipsol_codigo") );
    		tiposolicitacao.setTipsolDescri( (String) rs.getObject("tipsol_descri") );
                tiposolicitacao.setTipsolValor( (Double) rs.getObject("tipsol_valor") );
    		
    	}
        } catch( SQLException e ) {
            throw new SQLException(TiposolicitacaoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
    	return tiposolicitacao;
    }

    /**
     * getColecao
     * retorna todos os registros da tabela tiposolicitacao
     */
    public java.util.List <Tiposolicitacao> getColecao() throws SQLException {
        Tiposolicitacao tiposolicitacao = null;
        String sql = "SELECT tipsol_codigo, tipsol_descri, tipsol_valor " +
                     "FROM web.tiposolicitacao ";
        PreparedStatement ps = null;
        java.util.ArrayList <Tiposolicitacao> colec = new java.util.ArrayList();
        try {
            ps = conn.prepareStatement( sql );
            ResultSet rs = ps.executeQuery();
            while( rs.next() ) {
       		tiposolicitacao = new Tiposolicitacao();
      		tiposolicitacao.setTipsolCodigo( (Integer) rs.getObject("tipsol_codigo") );
    		tiposolicitacao.setTipsolDescri( (String) rs.getObject("tipsol_descri") );
                tiposolicitacao.setTipsolValor( (Double) rs.getObject("tipsol_valor") );
    		      
                  colec.add( tiposolicitacao );
            }
        } catch( SQLException e ) {
            throw new SQLException(TiposolicitacaoDAO.class+" - Cdigo: "+e.getErrorCode()+" Estado: "+e.getSQLState()+" Erro: "+e.getMessage() );
        } finally {
            if( ps != null ) {
                ps.close();
                ps = null;
            }
        }
        return colec;
    }
}
