/*
 * CaixaPretaAssinatura.java
 *
 * Created on 3 de Novembro de 2006, 14:45
 *
 * To change this template, choose Tools | Template Manager
 * and open the template in the editor.
 */

package br.com.tabelionatomessias.utils;

import java.io.*;
import java.security.*;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import org.w3c.dom.Document;
/**
 *
 * @author Michel
 */
public class CaixaPretaAssinatura {
    
    /** Creates a new instance of CaixaPretaAssinatura */
    private String algoritmo = "RSA";
    
    public CaixaPretaAssinatura() { }
    
    public static PrivateKey getPrivateKeyFromFile( File cert, String alias, String password ) throws Exception {
        KeyStore ks = KeyStore.getInstance ( "JKS" );
        char[] pwd = password.toCharArray();
        InputStream is = new FileInputStream( cert );
        ks.load( is, pwd );
        is.close();
        Key key = ks.getKey( alias, pwd );
        if( key instanceof PrivateKey ) {
            return (PrivateKey) key;
        }
        return null;
     }
 
     /**
      * Extrai a chave pblica do arquivo.
      */
     public static PublicKey getPublicKeyFromFile( File cert, String alias, String password ) throws Exception {
        KeyStore ks = KeyStore.getInstance ( "JKS" );
        char[] pwd = password.toCharArray();
        InputStream is = new FileInputStream( cert );
        ks.load( is, pwd );
        Key key = ks.getKey( alias, pwd );
        java.security.cert.Certificate c = ks.getCertificate( alias );
        PublicKey p = c.getPublicKey();
        return p;
     }
     
     /**
      * Retorna a assinatura para o buffer de bytes, usando a chave privada.
      * @param key PrivateKey
      * @param buffer Array de bytes a ser assinado.
      */
     public byte[] createSignature( PrivateKey key, byte[] buffer ) throws Exception {
        Signature sig = Signature.getInstance( algoritmo );
        sig.initSign(key);
        sig.update(buffer, 0, buffer.length);
        return sig.sign();
     }
 
     /**
      * Verifica a assinatura para o buffer de bytes, usando a chave pblica.
      * @param key PublicKey
      * @param buffer Array de bytes a ser verficado.
      * @param sgined Array de bytes assinado (encriptado) a ser verficado.
      */
     public boolean verifySignature( PublicKey key, byte[] buffer, byte[] signed ) throws Exception {
        Signature sig = Signature.getInstance( algoritmo );
        sig.initVerify(key);
        sig.update(buffer, 0, buffer.length);
        return sig.verify( signed );
     }
     
     public void assinar(byte[] arq, File cert) {
         try {
             XMLReader xml = new XMLReader();
             String senhaTabeliao = "";//xml.getParamValue("C:\\vcs\\pnotarium\\web\\web-inf\\web.xml");
             
             String alias = "guj";
             String pwd = "guj123";
 
             PrivateKey privateKey = getPrivateKeyFromFile( cert, alias, pwd );
             PublicKey publicKey = getPublicKeyFromFile( cert, alias, pwd );
 
             byte[] byAssinatura = createSignature( privateKey, arq );
             System.out.println( txt2Hexa( byAssinatura ) );
 
             if( verifySignature( publicKey, arq, byAssinatura ) ) {
                 System.out.println("Assinatura OK!");
             } else {
                 System.out.println("Assinatura NOT OK!");
             } 
         } catch( Exception e ) {
             e.printStackTrace();
         }
     }
     
    /**
      * Converte um array de byte em uma representao, em String, de seus hexadecimais.
      */
     public static String txt2Hexa(byte[] bytes) {
        if( bytes == null ) return null;
        String hexDigits = "0123456789abcdef";
        StringBuffer sbuffer = new StringBuffer();
        for (int i = 0; i < bytes.length; i++) {
            int j = ((int) bytes[i]) & 0xFF;
            sbuffer.append(hexDigits.charAt(j / 16));
            sbuffer.append(hexDigits.charAt(j % 16));
        }
        return sbuffer.toString();
     }
     
}
