/*
 * FileSigner.java
 *
 * Created on 29 de Janeiro de 2007, 22:31
 *
 */

package br.com.tabelionatomessias.utils;

import br.com.tabelionatomessias.interfaces.IConstantes;
import com.lowagie.text.DocumentException;
import com.lowagie.text.pdf.PdfReader;
import com.lowagie.text.pdf.PdfSignatureAppearance;
import com.lowagie.text.pdf.PdfStamper;
import com.sun.net.ssl.internal.ssl.PKCS12KeyStore;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.security.KeyStore;
import java.security.NoSuchAlgorithmException;
import java.security.PrivateKey;
import java.security.UnrecoverableKeyException;
import java.security.cert.Certificate;

/**
 * Assinar o PDF.
 */
public class FileSigner {
    
    // Variveis que contero os arquivos a serem utilizados na assinatura.
    private FileInputStream pdfPathIn;
    private FileOutputStream pdfPathOut;
    private FileInputStream certIn;
    
    /** Creates a new instance of FileSigner */
    public FileSigner() {
    }
    
    /**
     * Receber Assinar o PDF com o certificado passado
     *@param String senha
     *@param PKCS12KeyStore keyStore
     *@return FileOutputStream fout
     */
    public FileOutputStream assinarPDF(String senha, PKCS12KeyStore keyStore) throws DocumentException,
        NoSuchAlgorithmException, IOException, UnrecoverableKeyException {
        
        // Pegar as informaes do certificado.
        String alias = (String)keyStore.engineAliases().nextElement();
        PrivateKey key = (PrivateKey)keyStore.engineGetKey(alias, senha.toCharArray());
        Certificate[] chain = keyStore.engineGetCertificateChain(alias);
        
        // Arquivos a serem lidos e gravados
        PdfReader reader = new PdfReader(pdfPathIn);
        FileOutputStream fout = pdfPathOut;
        PdfStamper stp = PdfStamper.createSignature(reader, pdfPathOut, '\0');
        PdfSignatureAppearance sap = stp.getSignatureAppearance();
        
        // Assinar
        sap.setCrypto(key, chain, null, PdfSignatureAppearance.WINCER_SIGNED);
        sap.setReason(IConstantes.REASON);
        sap.setLocation(IConstantes.LOCATION);
        stp.close();

        return fout;
        
    }

    public FileInputStream getPdfPathIn() {
        return pdfPathIn;
    }

    public void setPdfPathIn(FileInputStream pdfPathIn) {
        this.pdfPathIn = pdfPathIn;
    }

    public FileOutputStream getPdfPathOut() {
        return pdfPathOut;
    }

    public void setPdfPathOut(FileOutputStream pdfPathOut) {
        this.pdfPathOut = pdfPathOut;
    }

    public FileInputStream getCertIn() {
        return certIn;
    }

    public void setCertIn(FileInputStream certIn) {
        this.certIn = certIn;
    }
}