/*
 * GeraCRL.java
 *
 * Created on 27 de Janeiro de 2007, 15:16
 *
 */

package br.com.tabelionatomessias.utils;

import br.com.tabelionatomessias.interfaces.IConstantes;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.math.BigInteger;
import java.security.InvalidKeyException;
import java.security.NoSuchProviderException;
import java.security.PrivateKey;
import java.security.SignatureException;
import java.security.cert.CRLException;
import java.security.cert.CertificateException;
import java.security.cert.CertificateFactory;
import java.security.cert.CertificateParsingException;
import java.security.cert.X509CRL;
import java.security.cert.X509CRLEntry;
import java.security.cert.X509Certificate;
import java.util.Date;
import java.util.HashSet;
import java.util.Iterator;
import javax.servlet.ServletContext;
import org.bouncycastle.asn1.x509.CRLNumber;
import org.bouncycastle.asn1.x509.CRLReason;
import org.bouncycastle.asn1.x509.X509Extensions;
import org.bouncycastle.x509.X509V2CRLGenerator;
import org.bouncycastle.x509.extension.AuthorityKeyIdentifierStructure;

/**
 * Gerao da lista de certificados revogados.
 */
public class GeraCRL {
    
    /** 
     * Creates a new instance of GeraCRL 
     */
    public GeraCRL() {
    }
    
    /**
     *Criar uma CRL ou atualizar uma j existente.
     *@param X509Certificate caCert
     *@param X509Certificate userCert
     *@param PrivateKey caKey
     *@param BigInteger revokedSerialNumber
     *@param HashSet lista
     *@return X509CRL x509crl
     *@throw CertificateParsingException, NoSuchProviderException, 
     *       SignatureException, InvalidKeyException
     */
    public static X509CRL createCRL( X509Certificate caCert, X509Certificate userCert,
                                     PrivateKey caKey, BigInteger revokedSerialNumber,
                                     HashSet lista) 
        throws CertificateParsingException, NoSuchProviderException, SignatureException, 
            InvalidKeyException {
       
        X509V2CRLGenerator crlGen = new X509V2CRLGenerator();
        Date now = new Date();
        
        crlGen.setIssuerDN(caCert.getSubjectX500Principal());
        crlGen.setThisUpdate(now);
        crlGen.setNextUpdate(now);
        crlGen.setSignatureAlgorithm(IConstantes.ALGORITMO_ASSINATURA);

        Iterator ite = lista.iterator();
        X509CRLEntry entry = null;
        Long iCont = Long.valueOf("1");
        
        while (ite.hasNext()) {
            entry = (X509CRLEntry)ite.next();
            if (entry != null) {
                crlGen.addCRLEntry(entry.getSerialNumber(), entry.getRevocationDate(), CRLReason.privilegeWithdrawn);
                iCont++;
            }
        }

        BigInteger bigCont = BigInteger.valueOf(iCont);
        crlGen.addCRLEntry(revokedSerialNumber, now, CRLReason.privilegeWithdrawn);
        crlGen.addExtension(X509Extensions.AuthorityKeyIdentifier, false, new AuthorityKeyIdentifierStructure(caCert));
        crlGen.addExtension(X509Extensions.CRLNumber, false, new CRLNumber(bigCont));

        return crlGen.generateX509CRL(caKey, "BC");
        
    }
    
    /**
     *Atualizar a CRL
     *@param ServletContext sc
     *@param PrivateKey pvKeyRoot
     *@param X509Certificate certUser
     *@param X509Certificate rootCert
     *throws IOException, CertificateException, CRLException ,
     *       NoSuchProviderException, SignatureException, InvalidKeyException
     */
    public void updateCRL(ServletContext sc, PrivateKey pvKeyRoot, X509Certificate certUser, 
            X509Certificate rootCert) throws IOException, CertificateException, CRLException ,
            NoSuchProviderException, SignatureException, InvalidKeyException {
      
        GeraCRL geraCRL = new GeraCRL();
        String raiz = sc.getRealPath(IConstantes.CAMINHO_RAIZ_APP);
        int idx = raiz.indexOf("build");
        String crlPath = raiz.substring(0, idx);
        crlPath = crlPath + IConstantes.CAMINHO_CRL_EXT;
        File arquivo = new File(crlPath);
        boolean criou = arquivo.createNewFile();

        FileInputStream crlInput = new FileInputStream(arquivo);    
        X509CRL crl = null;

        if (!criou) {
            CertificateFactory factory = CertificateFactory.getInstance("X509");
            crl = (X509CRL)factory.generateCRL(crlInput);
            HashSet<X509CRLEntry> list = new HashSet();
            list = (HashSet<X509CRLEntry>)crl.getRevokedCertificates();
            crl = (X509CRL)createCRL(rootCert, certUser, pvKeyRoot, certUser.getSerialNumber(), list);
        } else {
           crl = (X509CRL)createCRL(rootCert, certUser, pvKeyRoot, certUser.getSerialNumber(), new HashSet()); 
        }

        FileOutputStream out = new FileOutputStream(crlPath);
        out.write(crl.getEncoded());
        out.flush();
        out.close();
        crlInput.close();

    }

}
