/*
 * GeraCertificado.java
 *
 * Created on 2 de Novembro de 2006, 13:55
 *
 */

package br.com.tabelionatomessias.utils;

import br.com.tabelionatomessias.dao.cart.Pessoa;
import br.com.tabelionatomessias.interfaces.IConstantes;
import com.sun.net.ssl.internal.ssl.PKCS12KeyStore;
import java.security.cert.CertificateEncodingException;
import java.security.cert.CertificateException;
import java.security.cert.CertificateParsingException;
import javax.servlet.ServletContext;
import sun.misc.BASE64Encoder;
import java.io.*;
import java.math.BigInteger;
import java.security.*;
import java.security.cert.X509Certificate;
import java.text.SimpleDateFormat;
import java.util.*;
import org.bouncycastle.asn1.*;
import org.bouncycastle.asn1.pkcs.Attribute;
import org.bouncycastle.asn1.pkcs.PKCSObjectIdentifiers;
import org.bouncycastle.asn1.x509.*;
import org.bouncycastle.x509.*;
import org.bouncycastle.jce.PKCS10CertificationRequest;
import org.bouncycastle.x509.extension.AuthorityKeyIdentifierStructure;
import org.bouncycastle.x509.extension.SubjectKeyIdentifierStructure;
import javax.security.auth.x500.X500Principal;

/**
 * Tratar a gerao do certificado digital
 */
public class GeraCertificado {
    
    private String nome;
    private String email;
    private char[] senha;
    private byte[] userCertificate;

    /**
     *Mtodo que  chamado pelo servlet para a gerao do certificado.
     *Constri um certificado no padro X509
     *@param ServletContext sc
     *@param boolean geraRoot
     *@param PKCS12KeyStore rootCertFile
     *@param String senhaRoot
     *@param X509Certificate x509cert
     *@throws NoSuchAlgorithmException, NoSuchProviderException, InvalidKeyException, SignatureException, 
               UnrecoverableKeyException, CertificateParsingException, KeyStoreException, IOException, 
               CertificateException, CertificateEncodingException
     */
    public void buildChain(ServletContext sc, boolean geraRoot, PKCS12KeyStore rootCertFile, String senhaRoot, 
            X509Certificate x509cert, Integer codPessoa ) 
        throws NoSuchAlgorithmException, NoSuchProviderException, InvalidKeyException, SignatureException, 
               UnrecoverableKeyException, CertificateParsingException, KeyStoreException, IOException, 
               CertificateException, CertificateEncodingException {
        
        PrivateKey privKeyRoot = null;
        X509Certificate rootCert = null;
        KeyPair rootPair = null;
        
        // Cria uma requisio de certificado do usurio
        KeyPair pair = generateRSAKeyPair();
        PrivateKey privKeyUser = pair.getPrivate();
        PKCS10CertificationRequest request = generateRequest(pair);
        
        if (geraRoot) {            
            // Cria o certificado da AC
            rootPair = generateRSAKeyPair();
            rootCert = generateV3Certificate(rootPair);
        } else {
            // Usa o certificado j criado
            privKeyRoot = (PrivateKey)rootCertFile.engineGetKey(IConstantes.ALIAS_CERTIFICADO, senhaRoot.toCharArray());
            rootCert = x509cert;
            rootPair = new KeyPair(rootCert.getPublicKey(), privKeyRoot);
        }
        // Cria o certificado usando as informaes da requisio
        X509V3CertificateGenerator  certGen = new X509V3CertificateGenerator();        
        certGen.setSerialNumber(BigInteger.valueOf(System.currentTimeMillis()));
        certGen.setIssuerDN(rootCert.getSubjectX500Principal());
        
        Date a = new Date();
        certGen.setNotBefore(a);
        int ano = a.getYear();
        a.setYear(++ano);
        certGen.setNotAfter(a);
        
        certGen.setSubjectDN(request.getCertificationRequestInfo().getSubject());
        certGen.setPublicKey(request.getPublicKey(IConstantes.PROVIDER_CRIPTOGRAFIA));
        certGen.setSignatureAlgorithm(IConstantes.ALGORITMO_ASSINATURA);
        
        certGen.addExtension(X509Extensions.AuthorityKeyIdentifier, false, new AuthorityKeyIdentifierStructure(rootCert));
        certGen.addExtension(X509Extensions.SubjectKeyIdentifier, false, new SubjectKeyIdentifierStructure(request.getPublicKey(IConstantes.PROVIDER_CRIPTOGRAFIA)));
        certGen.addExtension(X509Extensions.BasicConstraints, true, new BasicConstraints(false));
        certGen.addExtension(X509Extensions.KeyUsage, true, new KeyUsage(KeyUsage.digitalSignature | KeyUsage.keyEncipherment | KeyUsage.nonRepudiation));
        certGen.addExtension(X509Extensions.ExtendedKeyUsage, true, new ExtendedKeyUsage(KeyPurposeId.id_kp_serverAuth));

        // Pega os atributos da requisio
        ASN1Set attributes = request.getCertificationRequestInfo().getAttributes();
        
        for (int i = 0; i != attributes.size(); i++) {
            Attribute attr = Attribute.getInstance(attributes.getObjectAt(i));
            
            // Adiciona as informaes da requisio
            if (attr.getAttrType().equals(PKCSObjectIdentifiers.pkcs_9_at_extensionRequest)) {
                X509Extensions extensions = X509Extensions.getInstance(attr.getAttrValues().getObjectAt(0));
                Enumeration e = extensions.oids();
                while (e.hasMoreElements()) {
                    DERObjectIdentifier oid = (DERObjectIdentifier)e.nextElement();
                    X509Extension ext = extensions.getExtension(oid);
                    certGen.addExtension(oid, ext.isCritical(), ext.getValue().getOctets());
                }
            }
        }
        // Gera o certificado, juntamente com informaes da AC
        X509Certificate  issuedCert = certGen.generateX509Certificate(rootPair.getPrivate());
        setUserCertificate(issuedCert.getEncoded());
        
        // Junta tudo em um [] de certificados
        X509Certificate[] certificate = new X509Certificate[] { issuedCert, rootCert };
        
        String path = sc.getRealPath(IConstantes.PASTA_WEB_INF);
        path = path + "\\temp\\Certificado" + codPessoa + ".p12";

        // Armazenar a chave privada junto com o certificado        
        FileOutputStream fios = new FileOutputStream(path);
        PKCS12KeyStore pk = new PKCS12KeyStore();
        pk.engineLoad(null, null);
        pk.engineSetKeyEntry(IConstantes.ALIAS_CERTIFICADO, privKeyUser, senha, certificate);
        pk.engineStore(fios, senha);
        fios.close();
        
        System.gc();
    }
    
    /**
     *Gera um par de chaves com o algoritmo RSA, usando 1024 bits
     *@return KeyPair keypair
     *@throws NoSuchAlgorithmException
     */
    public static KeyPair generateRSAKeyPair() throws NoSuchAlgorithmException {
        KeyPairGenerator  kpGen = KeyPairGenerator.getInstance(IConstantes.ALGORITMO_RSA);
        kpGen.initialize(1024, new SecureRandom());
        return kpGen.generateKeyPair();
    }
    
    /**
     *Gerar uma requisio de certificado
     *@param Keypair pair
     *@return PKCS10CertificationRequest certRequest
     *@throws NoSuchAlgorithmException, NoSuchProviderException, 
     * InvalidKeyException, SignatureException
     */
    public PKCS10CertificationRequest generateRequest(KeyPair pair) throws NoSuchAlgorithmException, 
                NoSuchProviderException, InvalidKeyException, SignatureException {
        
        // Cria um "apelido" para o dono do certificado
        GeneralNames  subjectAltNames = new GeneralNames( new GeneralName(GeneralName.rfc822Name, email));
        
        // Cria as extenses do certificado e adiciona os atributos
        Vector  oids = new Vector();
        Vector	values = new Vector();
        
        oids.add(X509Extensions.SubjectAlternativeName);
        values.add(new X509Extension(false, new DEROctetString(subjectAltNames)));        
        X509Extensions	extensions = new X509Extensions(oids, values);
        Attribute  attribute = new Attribute(PKCSObjectIdentifiers.pkcs_9_at_extensionRequest, new DERSet(extensions));
        
        return new PKCS10CertificationRequest(IConstantes.ALGORITMO_REQUISICAO, new X500Principal("CN = " + nome),
                pair.getPublic(), new DERSet(attribute), pair.getPrivate());
    }
    
    /**
     *Gera um certificado na verso 3 (V3)
     *@param KeyPair pair
     *@return X509Certificate x509cert
     *@throws InvalidKeyException, NoSuchProviderException, SignatureException
     */
    public X509Certificate generateV3Certificate(KeyPair pair) throws InvalidKeyException, 
            NoSuchProviderException, SignatureException {
        
        // Gera o certificado e seta os atributos
        X509V3CertificateGenerator certGen = new X509V3CertificateGenerator();        
        certGen.setSerialNumber(BigInteger.valueOf(System.currentTimeMillis()));
        certGen.setIssuerDN(new X500Principal(IConstantes.EMISSOR_CERTIFICADO));
        
        Date a = new Date();
        certGen.setNotBefore(a);
        int ano = a.getYear();
        a.setYear(++ano);
        certGen.setNotAfter(a);

        certGen.setSubjectDN(new X500Principal(IConstantes.EMISSOR_CERTIFICADO));
        certGen.setPublicKey(pair.getPublic());
        certGen.setSignatureAlgorithm(IConstantes.ALGORITMO_ASSINATURA);
        
        // inserido
        certGen.addExtension(X509Extensions.BasicConstraints, true, new BasicConstraints(false));
        certGen.addExtension(X509Extensions.KeyUsage, true, new KeyUsage(KeyUsage.digitalSignature | KeyUsage.keyEncipherment | KeyUsage.nonRepudiation));
        certGen.addExtension(X509Extensions.ExtendedKeyUsage, true, new ExtendedKeyUsage(KeyPurposeId.id_kp_serverAuth));

        return certGen.generateX509Certificate(pair.getPrivate());
        
    }
    
    public String getNome() {
        return nome;
    }
    
    public void setNome(String nome) {
        this.nome = nome;
    }
    
    public String getEmail() {
        return email;
    }
    
    public void setEmail(String email) {
        this.email = email;
    }
    
    public char[] getSenha() {
        return senha;
    }
    
    public void setSenha(char[] senha) {
        this.senha = senha;
    }

    public byte[] getUserCertificate() {
        return userCertificate;
    }

    public void setUserCertificate(byte[] userCertificate) {
        this.userCertificate = userCertificate;
    }
    
}