/*
 * GeraPDF.java
 *
 * Created on 15 de Fevereiro de 2007, 22:51
 *
 */

package br.com.tabelionatomessias.utils;

import br.com.tabelionatomessias.interfaces.IConstantes;
import com.lowagie.text.Document;
import com.lowagie.text.DocumentException;
import com.lowagie.text.Element;
import com.lowagie.text.Font;
import com.lowagie.text.FontFactory;
import com.lowagie.text.PageSize;
import com.lowagie.text.Paragraph;
import com.lowagie.text.pdf.PdfWriter;
import com.sun.net.ssl.internal.ssl.PKCS12KeyStore;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.security.NoSuchAlgorithmException;
import java.security.UnrecoverableKeyException;
import java.security.cert.CertificateException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import javax.xml.parsers.ParserConfigurationException;
import org.xml.sax.SAXException;

/**
 * Gerar um arquivo PDF.
 */
public class GeraPDF {
    
    /** Creates a new instance of GeraPDF */
    public GeraPDF() {
    }

    /**
     *Gerar o PDF assinado.
     *@param int[] vet1
     *@param String[] vet2
     *@param HashMap mapa
     *@param String path
     *@param String webinfPath
     *@param String codVerifi
     *@throws IOException, DocumentException, ParserConfigurationException, 
     *        SAXException, FileNotFoundException, NoSuchAlgorithmException, 
     *        CertificateException, DocumentException, UnrecoverableKeyException
     *@return FileInputStream fiospdf
     */
    public FileInputStream gerarPDF(int[] vet1, String[] vet2, HashMap mapa, String path, 
            String webinfPath, int codigo, String codVerfi) throws IOException, DocumentException, ParserConfigurationException, 
            SAXException, FileNotFoundException, NoSuchAlgorithmException, 
            CertificateException, DocumentException, UnrecoverableKeyException {
        
            Document document = new Document();
            document.setPageSize(PageSize.A4);

            File file = new File(path);
            file.createNewFile();
            FileOutputStream fiospdf = new FileOutputStream(file);
            PdfWriter.getInstance(document, fiospdf);
            document.open();
            Paragraph paragraph = new Paragraph();
            
            Font font = FontFactory.getFont(FontFactory.HELVETICA_BOLDOBLIQUE, 18, Font.HELVETICA);  
            Paragraph cabecalho1 = new Paragraph("",font);
            cabecalho1.setAlignment(Element.ALIGN_CENTER);
            cabecalho1.add("Tabelionato Messias");
            document.add(cabecalho1);
            cabecalho1.clear();

            font = FontFactory.getFont(FontFactory.HELVETICA_BOLDOBLIQUE, 14, Font.HELVETICA);  
            Paragraph cabecalho2 = new Paragraph("",font);
            cabecalho2.setAlignment(Element.ALIGN_CENTER);
            cabecalho2.add("4 Ofcio de Notas da Comarca de Ponta Grossa/PR");
            document.add(cabecalho2);
            cabecalho2.clear();

            font = FontFactory.getFont(FontFactory.HELVETICA_BOLD, 10, Font.HELVETICA);  
            Paragraph cabecalho3 = new Paragraph("",font);
            cabecalho3.setAlignment(Element.ALIGN_CENTER);
            cabecalho3.add("Rua Quinze de Novembro 357 - Centro - Ponta Grossa PR"); 
            document.add(cabecalho3);

            cabecalho3.clear();
            cabecalho3.add(" ");
            document.add(cabecalho3);
            
            /* Montar o PDF de acordo com os comandos e respectivos
             * valores passados nos vetores. A montagem funciona assim:
             * O primeiro vetor de ints so os 4 comandos abaixo que
             * podem ser executados, o outro vetor de Strings  o respectivo 
             * valor para aquele determinado comando. No caso dos comandos 
             * "document.add" e "paragraph.clear", o valor  null, para
             * os outros,  necessrio passaro o valor (contedo do pargrafo
             * ou alinhamento).
             */
            for (int k = 0; k <= vet1.length - 1; k++) {
                switch(vet1[k]) {
                    
                    // 0 = paragraph.add
                    case 0: paragraph.add(vet2[k]); break;
                    
                    // 1 = paragraph.clear
                    case 1: paragraph.clear(); break;
                    
                    // 2 = paragraph.setAligment                
                    case 2: Integer i = (Integer)mapa.get(vet2[k]);
                            paragraph.setAlignment(i.intValue());
                            break;
                    
                    // 3 = document.add
                    case 3: document.add(paragraph); break;
                }
            }
            
            SimpleDateFormat format = new SimpleDateFormat("dd/MM/yyyy HH:mm:ss");
            java.util.Date data = new Date();
            String dataFormatada = format.format(data);            
            
            paragraph.setAlignment(Element.ALIGN_CENTER);                   
            paragraph.clear();
            paragraph.add(IConstantes.CERT_TEXTO2 + dataFormatada);
            document.add(paragraph);

            paragraph.clear();
            paragraph.add(" ");
            document.add(paragraph);

            paragraph.clear();
            paragraph.add(IConstantes.CERT_TABELIAO);
            document.add(paragraph);

            paragraph.clear();
            paragraph.add(IConstantes.CERT_NUM_TABELIAO);
            document.add(paragraph);

            paragraph.clear();
            paragraph.add(" ");
            document.add(paragraph);

            font = FontFactory.getFont(FontFactory.TIMES_ROMAN, 11, Font.BOLDITALIC);  
            Paragraph paragraph1 = new Paragraph("",font);
            paragraph1.setAlignment(Element.ALIGN_CENTER);  
            paragraph1.clear();
            paragraph1.add("A autenticidade desta certido poder ser confirmada " +
                           "gratuitamente na pgina do Tabelionato Messias na Internet, " +
                           "no endereo: http://www.tabelionatomessias.com.br, " +
                           "atravs do cdigo: : " + codVerfi);
            document.add(paragraph1);
            
            document.close();
            fiospdf.flush();
            fiospdf.close();            
            
            return assinarPDF(webinfPath, codigo);

    }
    
    /**
     *Chamar a classe de assinatura de PDF e devolver esse PDF assinado.
     *@param String webinfPath
     *@return FileInputStream retorno
     *@throws ParserConfigurationException, SAXException, FileNotFoundException, 
     *        IOException, NoSuchAlgorithmException, CertificateException, 
     *        DocumentException, UnrecoverableKeyException
     */
    private FileInputStream assinarPDF(String webinfPath, int codigo) throws ParserConfigurationException,
        SAXException, FileNotFoundException, IOException, NoSuchAlgorithmException, 
        CertificateException, DocumentException, UnrecoverableKeyException {
        
        String pathCertidao1 = null;
        String pathCertidao2 = null;
        switch (codigo) {
            case IConstantes.COD_SOLIC_CERTIDAO: 
                pathCertidao1 = webinfPath + IConstantes.CAMINHO_CERTIDAO_INP;
                pathCertidao2 = webinfPath + IConstantes.CAMINHO_CERTIDAO_OUT;
                break;
            case IConstantes.COD_SOLIC_VERIF_REG_DOCS:
                pathCertidao1 = webinfPath + IConstantes.CAMINHO_CERTIDAO_VERIF_INP;
                pathCertidao2 = webinfPath + IConstantes.CAMINHO_CERTIDAO_VERIF_OUT;
                break;                
        }

        // Pegar a senha do tabelio para fazer a assinatura.
        String pathXml = webinfPath + IConstantes.WEB_XML;
        String valoresXml[] = new String[] {pathXml, "param-name", "param-value"};
        XMLReader xml = new XMLReader();
        Map map = xml.getParamValue(valoresXml);
        String senhaTabeliao = (String) map.get("Senha");                

        // Carregar o arquivo de certficado do tabelionato.
        String certPath = webinfPath + IConstantes.CAMINHO_CERTIFICADO_ROOT;
        FileInputStream arquivoCert = new FileInputStream(certPath);
        PKCS12KeyStore rootCertFile = new PKCS12KeyStore();
        rootCertFile.engineLoad(arquivoCert, senhaTabeliao.toCharArray());
        arquivoCert.close();

        // Arquivos de entrada e sada do PDF.
        FileInputStream input = new FileInputStream(pathCertidao2);
        FileOutputStream output = new FileOutputStream(pathCertidao1);

        // Setar os arquivos na classe e pegar o PDF assinado.
        FileSigner signer = new FileSigner();
        signer.setPdfPathIn(input);
        signer.setPdfPathOut(output);
        signer.setCertIn(arquivoCert);
        output = signer.assinarPDF(senhaTabeliao, rootCertFile);
      
        output.flush();
        output.close();
        input.close();
        
        return new FileInputStream(pathCertidao1);
        
    }
    
    public String gerarCodigoValidacao(int ano, int solser) {
        String letras = "ABCDEFGHIJKLMNOPQRSTUVXYZ0123456789";
        String codigo = null;
        codigo = ano + ".";
        for ( int i = 1; i <= 8; i++ )   {
           char nextNum = letras.charAt(getNumAleatorio(letras.length())); 
           if (i == 5) { codigo = codigo + "."; }
           codigo = codigo + nextNum;
        }
        codigo = codigo + "-" + solser;
        return codigo;
    }
    
    public int getNumAleatorio(int max) { 
        max = max + 1;
        int valor = (int) (Math.random() * max);
        return valor;
    }
}
